-- shard help unit table for BA

unitTable = {}

unitTable["aafus"] = { radarRadius = 0, techLevel = 5, isBuilding = true, buildTime = 312498, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 409.5, losRadius = 273, wreckName = "aafus_dead", sonarRadius = 0, metalCost = 9716, xsize = 14, submergedRange = 0, jammerRadius = 0, zsize = 10, energyCost = 68389, mtype = "veh", airRange = 0, totalEnergyOut = 3000, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["ajuno"] = { radarRadius = 0, techLevel = 3, isBuilding = true, buildTime = 21833, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 741, losRadius = 494, wreckName = "ajuno_dead", sonarRadius = 0, metalCost = 637, xsize = 8, submergedRange = 0, jammerRadius = 0, zsize = 8, energyCost = 17686, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = true, groundRange = 32000, isWeapon = true, }
unitTable["amgeo"] = { radarRadius = 0, techLevel = 5, isBuilding = true, buildTime = 33152, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 409.5, losRadius = 273, wreckName = "", sonarRadius = 0, metalCost = 1621, xsize = 10, submergedRange = 0, jammerRadius = 0, zsize = 16, energyCost = 26509, mtype = "veh", airRange = 0, totalEnergyOut = 1250, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armaak"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 6958, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 925, losRadius = 400, wreckName = "armaak_dead", sonarRadius = 0, metalCost = 515, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 5617, mtype = "bot", airRange = 875, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = true, }
unitTable["armaap"] = { radarRadius = 0, techLevel = 3, isBuilding = true, buildTime = 20851, factoriesCanBuild = { }, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 468, wreckName = "armaap_dead", losRadius = 312, zsize = 12, sonarRadius = 0, metalCost = 3206, xsize = 16, submergedRange = 0, jammerRadius = 0, buildOptions = true, energyCost = 28785, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armaas"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 8628, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 900, losRadius = 475, wreckName = "armaas_dead", sonarRadius = 0, metalCost = 702, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 7529, mtype = "shp", airRange = 840, totalEnergyOut = 4.5, stealth = false, groundRange = 0, isWeapon = true, }
unitTable["armaca"] = { radarRadius = 50, techLevel = 4, isBuilding = false, buildTime = 17763, factoriesCanBuild = { "armap", "armaap", "armplat", }, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 575.25, wreckName = "", losRadius = 383.5, zsize = 4, sonarRadius = 0, metalCost = 282, xsize = 4, submergedRange = 0, jammerRadius = 0, buildOptions = true, energyCost = 11642, mtype = "air", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armack"] = { radarRadius = 50, techLevel = 4, isBuilding = false, buildTime = 9432, factoriesCanBuild = { "armshltx", "armlab", "armalab", }, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 485.550018, wreckName = "armack_dead", losRadius = 323.700012, zsize = 4, sonarRadius = 0, metalCost = 370, xsize = 4, submergedRange = 0, jammerRadius = 0, buildOptions = true, energyCost = 6534, mtype = "bot", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armacsub"] = { radarRadius = 50, techLevel = 4, isBuilding = false, buildTime = 23900, factoriesCanBuild = { "armplat", "armsy", "armasy", "armshltxuw", "asubpen", }, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 234, wreckName = "armacsub_dead", losRadius = 156, zsize = 6, sonarRadius = 0, metalCost = 848, xsize = 6, submergedRange = 0, jammerRadius = 0, buildOptions = true, energyCost = 11486, mtype = "sub", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armacv"] = { radarRadius = 50, techLevel = 4, isBuilding = false, buildTime = 12397, factoriesCanBuild = { "armvp", "armavp", }, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 434.849976, wreckName = "armacv_dead", losRadius = 289.899994, zsize = 6, sonarRadius = 0, metalCost = 552, xsize = 6, submergedRange = 0, jammerRadius = 0, buildOptions = true, energyCost = 6736, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armadvsol"] = { radarRadius = 0, techLevel = 3, isBuilding = true, buildTime = 7945, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 390, losRadius = 260, wreckName = "armadvsol_dead", sonarRadius = 0, metalCost = 366, xsize = 8, submergedRange = 0, jammerRadius = 0, zsize = 8, energyCost = 5040, mtype = "veh", airRange = 0, totalEnergyOut = 75, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armah"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 3565, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 800, losRadius = 509, wreckName = "armah_dead", sonarRadius = 350, metalCost = 231, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 4519, mtype = "hov", airRange = 800, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = true, }
unitTable["armalab"] = { radarRadius = 50, techLevel = 3, isBuilding = true, buildTime = 16224, factoriesCanBuild = { }, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 429, wreckName = "armalab_dead", losRadius = 286, zsize = 12, sonarRadius = 0, metalCost = 2911, xsize = 12, submergedRange = 0, jammerRadius = 0, buildOptions = true, energyCost = 14678, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armamb"] = { radarRadius = 0, techLevel = 5, isBuilding = true, buildTime = 27072, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 663, losRadius = 442, wreckName = "armamb_dead", sonarRadius = 0, metalCost = 2498, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 17942, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 1320, isWeapon = true, }
unitTable["armamd"] = { radarRadius = 50, techLevel = 5, isBuilding = true, buildTime = 60000, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 301.5, losRadius = 201, wreckName = "armamd_dead", sonarRadius = 0, metalCost = 1493, xsize = 8, submergedRange = 0, jammerRadius = 0, zsize = 8, energyCost = 38400, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 72000, isWeapon = true, }
unitTable["armamex"] = { radarRadius = 0, techLevel = 3, isBuilding = true, buildTime = 1800, needsWater = false, extractsMetal = 0.001, bigExplosion = false, airLosRadius = 429, losRadius = 286, wreckName = "armamex_dead", sonarRadius = 0, metalCost = 203, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 1776, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = true, groundRange = 0, isWeapon = false, }
unitTable["armamph"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 5182, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 565.5, losRadius = 377, wreckName = "armamph_dead", sonarRadius = 0, metalCost = 261, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 2633, mtype = "bot", airRange = 600, totalEnergyOut = 0, stealth = false, groundRange = 275, isWeapon = true, }
unitTable["armanac"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 3194, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 763.5, losRadius = 509, wreckName = "armanac_dead", sonarRadius = 0, metalCost = 287, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 2607, mtype = "hov", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 320, isWeapon = true, }
unitTable["armanni"] = { radarRadius = 1500, techLevel = 5, isBuilding = true, buildTime = 52071, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 1170, losRadius = 780, wreckName = "armanni_dead", sonarRadius = 0, metalCost = 3502, xsize = 8, submergedRange = 0, jammerRadius = 0, zsize = 8, energyCost = 73407, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 1400, isWeapon = true, }
unitTable["armap"] = { radarRadius = 500, techLevel = 1, isBuilding = true, buildTime = 7240, factoriesCanBuild = { }, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 438, wreckName = "armap_dead", losRadius = 292, zsize = 12, sonarRadius = 0, metalCost = 907, xsize = 16, submergedRange = 0, jammerRadius = 0, buildOptions = true, energyCost = 1461, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armarad"] = { radarRadius = 3500, techLevel = 5, isBuilding = true, buildTime = 11800, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 1230, losRadius = 820, wreckName = "armarad_dead", sonarRadius = 0, metalCost = 560, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 19019, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armaser"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 4937, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 390, losRadius = 260, wreckName = "armaser_dead", sonarRadius = 0, metalCost = 78, xsize = 4, submergedRange = 0, jammerRadius = 450, zsize = 4, energyCost = 1414, mtype = "bot", airRange = 0, totalEnergyOut = -100, stealth = false, groundRange = 800, isWeapon = false, }
unitTable["armason"] = { radarRadius = 0, techLevel = 5, isBuilding = true, buildTime = 6152, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 322.5, losRadius = 215, wreckName = "armason_dead", sonarRadius = 2400, metalCost = 174, xsize = 8, submergedRange = 0, jammerRadius = 0, zsize = 8, energyCost = 2634, mtype = "sub", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armasp"] = { radarRadius = 0, techLevel = 3, isBuilding = true, buildTime = 9090, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 536.25, losRadius = 357.5, wreckName = "armasp_dead", sonarRadius = 0, metalCost = 399, xsize = 18, submergedRange = 0, jammerRadius = 0, zsize = 18, energyCost = 4350, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armasy"] = { radarRadius = 50, techLevel = 3, isBuilding = true, buildTime = 15972, factoriesCanBuild = { }, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 448.5, wreckName = "armasy_dead", losRadius = 299, zsize = 24, sonarRadius = 0, metalCost = 3187, xsize = 24, submergedRange = 0, jammerRadius = 0, buildOptions = true, energyCost = 9702, mtype = "shp", airRange = 0, totalEnergyOut = 25, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armatl"] = { radarRadius = 0, techLevel = -1, isBuilding = true, buildTime = 6532, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 700, losRadius = 400, wreckName = "armatl_dead", sonarRadius = 0, metalCost = 389, xsize = 8, submergedRange = 0, jammerRadius = 0, zsize = 8, energyCost = 4478, mtype = "shp", airRange = 650, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = true, }
unitTable["armatlas"] = { radarRadius = 0, techLevel = 2, isBuilding = false, buildTime = 3850, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 390, losRadius = 260, wreckName = "", sonarRadius = 0, metalCost = 68, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 1322, mtype = "air", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = true, }
unitTable["armavp"] = { radarRadius = 50, techLevel = 3, isBuilding = true, buildTime = 17940, factoriesCanBuild = { }, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 425.099976, wreckName = "armavp_dead", losRadius = 283.399994, zsize = 12, sonarRadius = 0, metalCost = 2878, xsize = 14, submergedRange = 0, jammerRadius = 0, buildOptions = true, energyCost = 14336, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armawac"] = { radarRadius = 2500, techLevel = 4, isBuilding = false, buildTime = 12819, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 1912.5, losRadius = 1275, wreckName = "", sonarRadius = 1200, metalCost = 176, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 8599, mtype = "air", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armbanth"] = { radarRadius = 0, techLevel = 6, isBuilding = false, buildTime = 276057, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 1100, losRadius = 617, wreckName = "armbanth_dead", sonarRadius = 0, metalCost = 13537, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 285812, mtype = "bot", airRange = 800, totalEnergyOut = 12, stealth = false, groundRange = 800, isWeapon = true, }
unitTable["armbats"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 58730, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 682.5, losRadius = 455, wreckName = "armbats_dead", sonarRadius = 0, metalCost = 5526, xsize = 12, submergedRange = 0, jammerRadius = 0, zsize = 12, energyCost = 22113, mtype = "shp", airRange = 0, totalEnergyOut = 56.5, stealth = false, groundRange = 1240, isWeapon = true, }
unitTable["armbeaver"] = { radarRadius = 0, techLevel = 2, isBuilding = false, buildTime = 6708, factoriesCanBuild = { "armlab", "armvp", "armap", "armhp", "armfhp", "armsy", "asubpen", }, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 399, wreckName = "armbeaver_dead", losRadius = 266, zsize = 6, sonarRadius = 0, metalCost = 150, xsize = 6, submergedRange = 0, jammerRadius = 0, buildOptions = true, energyCost = 3123, mtype = "amp", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armbrawl"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 13294, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 825, losRadius = 550, wreckName = "", sonarRadius = 0, metalCost = 314, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 6163, mtype = "air", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 380, isWeapon = true, }
unitTable["armbrtha"] = { radarRadius = 0, techLevel = 5, isBuilding = true, buildTime = 85185, needsWater = false, extractsMetal = 0, bigExplosion = true, airLosRadius = 409.5, losRadius = 273, wreckName = "armbrtha_dead", sonarRadius = 0, metalCost = 4463, xsize = 8, submergedRange = 0, jammerRadius = 0, zsize = 8, energyCost = 64725, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 4650, isWeapon = true, }
unitTable["armbull"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 17228, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 741, losRadius = 494, wreckName = "armbull_dead", sonarRadius = 0, metalCost = 900, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 13232, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 460, isWeapon = true, }
unitTable["armca"] = { radarRadius = 0, techLevel = 2, isBuilding = false, buildTime = 8844, factoriesCanBuild = { "armaap", "armlab", "armvp", "armap", "armhp", "armsy", }, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 585, wreckName = "", losRadius = 390, zsize = 4, sonarRadius = 0, metalCost = 112, xsize = 4, submergedRange = 0, jammerRadius = 0, buildOptions = true, energyCost = 4608, mtype = "air", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armcarry"] = { radarRadius = 2950, techLevel = 4, isBuilding = false, buildTime = 20800, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 1657.5, losRadius = 1105, wreckName = "armcarry_dead", sonarRadius = 760, metalCost = 1707, xsize = 12, submergedRange = 0, jammerRadius = 0, zsize = 12, energyCost = 22187, mtype = "shp", airRange = 0, totalEnergyOut = 229.5, stealth = false, groundRange = 72000, isWeapon = false, }
unitTable["armch"] = { radarRadius = 50, techLevel = 4, isBuilding = false, buildTime = 4472, factoriesCanBuild = { "armlab", "armvp", "armap", "armhp", "armfhp", "armsy", "asubpen", }, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 526.5, wreckName = "armch_dead", losRadius = 351, zsize = 6, sonarRadius = 0, metalCost = 145, xsize = 6, submergedRange = 0, jammerRadius = 0, buildOptions = true, energyCost = 2691, mtype = "hov", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armcir"] = { radarRadius = 0, techLevel = 3, isBuilding = true, buildTime = 12004, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 1000, losRadius = 350, wreckName = "armcir_dead", sonarRadius = 0, metalCost = 749, xsize = 8, submergedRange = 0, jammerRadius = 0, zsize = 8, energyCost = 8688, mtype = "veh", airRange = 1050, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = true, }
unitTable["armck"] = { radarRadius = 0, techLevel = 2, isBuilding = false, buildTime = 3453, factoriesCanBuild = { "armalab", "armlab", "armvp", "armap", "armhp", "armsy", }, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 457.5, wreckName = "armck_dead", losRadius = 305, zsize = 4, sonarRadius = 0, metalCost = 109, xsize = 4, submergedRange = 0, jammerRadius = 0, buildOptions = true, energyCost = 1622, mtype = "bot", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armckfus"] = { radarRadius = 0, techLevel = 5, isBuilding = true, buildTime = 84389, needsWater = false, extractsMetal = 0, bigExplosion = true, airLosRadius = 409.5, losRadius = 273, wreckName = "armckfus_dead", sonarRadius = 0, metalCost = 4660, xsize = 10, submergedRange = 0, jammerRadius = 0, zsize = 8, energyCost = 26289, mtype = "veh", airRange = 0, totalEnergyOut = 1050, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armclaw"] = { radarRadius = 0, techLevel = 3, isBuilding = false, buildTime = 4638, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 660, losRadius = 440, wreckName = "armclaw_dead", sonarRadius = 0, metalCost = 336, xsize = 4, submergedRange = 0, jammerRadius = 8, zsize = 4, energyCost = 1649, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = true, groundRange = 440, isWeapon = true, }
unitTable["armcom"] = { radarRadius = 700, techLevel = 0, isBuilding = false, buildTime = 75000, factoriesCanBuild = { "armlab", "armvp", "armap", "armsy", }, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 675, wreckName = "armcom_dead", losRadius = 450, zsize = 4, sonarRadius = 450, metalCost = 2667, xsize = 4, submergedRange = 260, jammerRadius = 0, buildOptions = true, energyCost = 26667, mtype = "veh", airRange = 0, totalEnergyOut = 25, stealth = false, groundRange = 300, isWeapon = true, }
unitTable["armcroc"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 13367, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 558, losRadius = 372, wreckName = "armcroc_dead", sonarRadius = 0, metalCost = 498, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 12279, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 480, isWeapon = true, }
unitTable["armcrus"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 19789, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 858, losRadius = 572, wreckName = "armcrus_dead", sonarRadius = 375, metalCost = 1834, xsize = 8, submergedRange = 500, jammerRadius = 0, zsize = 8, energyCost = 14515, mtype = "shp", airRange = 0, totalEnergyOut = 4.5999999, stealth = false, groundRange = 740, isWeapon = true, }
unitTable["armcs"] = { radarRadius = 0, techLevel = 2, isBuilding = false, buildTime = 7686, factoriesCanBuild = { "armsy", "armasy", "armfhp", "asubpen", "armplat", }, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 436.800018, wreckName = "armcs_dead", losRadius = 291.200012, zsize = 6, sonarRadius = 0, metalCost = 272, xsize = 6, submergedRange = 0, jammerRadius = 0, buildOptions = true, energyCost = 2272, mtype = "shp", airRange = 0, totalEnergyOut = 19.5, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armcsa"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 20098, factoriesCanBuild = { "armap", "armaap", "armplat", "armsy", "armasy", }, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 546, wreckName = "", losRadius = 364, zsize = 4, sonarRadius = 0, metalCost = 271, xsize = 4, submergedRange = 0, jammerRadius = 0, buildOptions = true, energyCost = 25677, mtype = "air", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armcv"] = { radarRadius = 50, techLevel = 2, isBuilding = false, buildTime = 4066, factoriesCanBuild = { "armavp", "armlab", "armvp", "armap", "armhp", "armsy", }, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 379.5, wreckName = "armcv_dead", losRadius = 253, zsize = 6, sonarRadius = 0, metalCost = 137, xsize = 6, submergedRange = 0, jammerRadius = 0, buildOptions = true, energyCost = 1922, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armcybr"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 56203, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 682.5, losRadius = 455, wreckName = "", sonarRadius = 0, metalCost = 2243, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 43062, mtype = "air", airRange = 0, totalEnergyOut = -40, stealth = false, groundRange = 250, isWeapon = true, }
unitTable["armdecom"] = { radarRadius = 50, techLevel = 4, isBuilding = false, buildTime = 24048, factoriesCanBuild = { }, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 565.5, wreckName = "", losRadius = 377, zsize = 4, sonarRadius = 0, metalCost = 769, xsize = 4, submergedRange = 0, jammerRadius = 0, buildOptions = true, energyCost = 12332, mtype = "veh", airRange = 0, totalEnergyOut = 15, stealth = false, groundRange = 300, isWeapon = true, }
unitTable["armdf"] = { radarRadius = 0, techLevel = 5, isBuilding = true, buildTime = 7500, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 315, losRadius = 210, wreckName = "armdf_dead", sonarRadius = 0, metalCost = 365, xsize = 10, submergedRange = 0, jammerRadius = 0, zsize = 8, energyCost = 107, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armdfly"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 16022, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 477, losRadius = 318, wreckName = "", sonarRadius = 0, metalCost = 318, xsize = 8, submergedRange = 0, jammerRadius = 0, zsize = 8, energyCost = 6667, mtype = "air", airRange = 0, totalEnergyOut = 0, stealth = true, groundRange = 520, isWeapon = false, }
unitTable["armdl"] = { radarRadius = 0, techLevel = 1, isBuilding = true, buildTime = 4180, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 925.5, losRadius = 617, wreckName = "armdl_dead", sonarRadius = 515, metalCost = 288, xsize = 4, submergedRange = 580, jammerRadius = 0, zsize = 4, energyCost = 2515, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = true, }
unitTable["armdrag"] = { radarRadius = 0, techLevel = 1, isBuilding = true, buildTime = 255, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 1.5, losRadius = 1, wreckName = "armdrag_rockteeth", sonarRadius = 0, metalCost = 11, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 160, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armemp"] = { radarRadius = 0, techLevel = 5, isBuilding = true, buildTime = 79247, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 682.5, losRadius = 455, wreckName = "armemp_dead", sonarRadius = 0, metalCost = 1601, xsize = 8, submergedRange = 0, jammerRadius = 0, zsize = 8, energyCost = 28978, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 4500, isWeapon = true, }
unitTable["armestor"] = { radarRadius = 0, techLevel = 1, isBuilding = true, buildTime = 4119, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 409.5, losRadius = 273, wreckName = "armestor_dead", sonarRadius = 0, metalCost = 170, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 1698, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armeyes"] = { radarRadius = 0, techLevel = 1, isBuilding = true, buildTime = 750, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 840, losRadius = 560, wreckName = "armeyes_dragonseyes_dead", sonarRadius = 0, metalCost = 32, xsize = 2, submergedRange = 0, jammerRadius = 0, zsize = 2, energyCost = 853, mtype = "veh", airRange = 0, totalEnergyOut = -3, stealth = true, groundRange = 0, isWeapon = false, }
unitTable["armfark"] = { radarRadius = 50, techLevel = 4, isBuilding = false, buildTime = 4302, factoriesCanBuild = { }, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 565.5, wreckName = "armfark_dead", losRadius = 377, zsize = 4, sonarRadius = 0, metalCost = 214, xsize = 4, submergedRange = 0, jammerRadius = 0, buildOptions = true, energyCost = 2979, mtype = "bot", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armfast"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 3960, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 526.5, losRadius = 351, wreckName = "armfast_dead", sonarRadius = 0, metalCost = 189, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 4674, mtype = "bot", airRange = 0, totalEnergyOut = 0.40000001, stealth = false, groundRange = 220, isWeapon = true, }
unitTable["armfatf"] = { radarRadius = 0, techLevel = 5, isBuilding = true, buildTime = 9886, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 409.5, losRadius = 273, wreckName = "armfatf_dead", sonarRadius = 0, metalCost = 806, xsize = 8, submergedRange = 0, jammerRadius = 0, zsize = 8, energyCost = 7257, mtype = "shp", airRange = 0, totalEnergyOut = -150, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armfav"] = { radarRadius = 0, techLevel = 2, isBuilding = false, buildTime = 912, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 877.5, losRadius = 585, wreckName = "armfav_dead", sonarRadius = 0, metalCost = 31, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 365, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 180, isWeapon = true, }
unitTable["armfboy"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 22397, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 765, losRadius = 510, wreckName = "armfboy_dead", sonarRadius = 0, metalCost = 1513, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 11939, mtype = "bot", airRange = 0, totalEnergyOut = 0.0999999, stealth = false, groundRange = 700, isWeapon = true, }
unitTable["armfdrag"] = { radarRadius = 0, techLevel = 1, isBuilding = true, buildTime = 930, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 1.5, losRadius = 1, wreckName = "", sonarRadius = 0, metalCost = 21, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 640, mtype = "shp", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armfflak"] = { radarRadius = 0, techLevel = 5, isBuilding = true, buildTime = 21855, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 1000, losRadius = 550, wreckName = "armfflak_dead", sonarRadius = 0, metalCost = 861, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 23233, mtype = "shp", airRange = 775, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = true, }
unitTable["armfgate"] = { radarRadius = 0, techLevel = -1, isBuilding = false, buildTime = 59060, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 900, losRadius = 600, wreckName = "armfgate_dead", sonarRadius = 0, metalCost = 3917, xsize = 8, submergedRange = 0, jammerRadius = 0, zsize = 8, energyCost = 72048, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 600, isWeapon = false, }
unitTable["armfhlt"] = { radarRadius = 0, techLevel = 3, isBuilding = true, buildTime = 9670, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 936, losRadius = 624, wreckName = "armfhlt_dead", sonarRadius = 0, metalCost = 559, xsize = 8, submergedRange = 0, jammerRadius = 0, zsize = 8, energyCost = 6182, mtype = "shp", airRange = 0, totalEnergyOut = 5, stealth = false, groundRange = 620, isWeapon = true, }
unitTable["armfhp"] = { radarRadius = 50, techLevel = 2.5, isBuilding = true, buildTime = 17362, factoriesCanBuild = { }, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 429, wreckName = "armfhp_dead", losRadius = 286, zsize = 14, sonarRadius = 0, metalCost = 1100, xsize = 16, submergedRange = 0, jammerRadius = 0, buildOptions = true, energyCost = 5277, mtype = "shp", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armfido"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 6232, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 600, losRadius = 400, wreckName = "armfido_dead", sonarRadius = 0, metalCost = 270, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 5615, mtype = "bot", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 650, isWeapon = true, }
unitTable["armfig"] = { radarRadius = 0, techLevel = 2, isBuilding = false, buildTime = 3465, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 700, losRadius = 200, wreckName = "", sonarRadius = 0, metalCost = 73, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 2866, mtype = "air", airRange = 530, totalEnergyOut = 0, stealth = false, groundRange = 530, isWeapon = true, }
unitTable["armflak"] = { radarRadius = 0, techLevel = 5, isBuilding = true, buildTime = 19005, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 1000, losRadius = 525, wreckName = "armflak_dead", sonarRadius = 0, metalCost = 820, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 13011, mtype = "veh", airRange = 775, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = true, }
unitTable["armflash"] = { radarRadius = 0, techLevel = 2, isBuilding = false, buildTime = 1963, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 448.5, losRadius = 299, wreckName = "armflash_dead", sonarRadius = 0, metalCost = 116, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 975, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 180, isWeapon = true, }
unitTable["armflea"] = { radarRadius = 0, techLevel = 2, isBuilding = false, buildTime = 789, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 825, losRadius = 550, wreckName = "armflea_dead", sonarRadius = 0, metalCost = 15, xsize = 2, submergedRange = 0, jammerRadius = 0, zsize = 2, energyCost = 343, mtype = "bot", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 140, isWeapon = true, }
unitTable["armfmine3"] = { radarRadius = 0, techLevel = 5, isBuilding = false, buildTime = 150, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 117, losRadius = 78, wreckName = "", sonarRadius = 0, metalCost = 27, xsize = 2, submergedRange = 0, jammerRadius = 0, zsize = 2, energyCost = 1600, mtype = "hov", airRange = 0, totalEnergyOut = 0, stealth = true, groundRange = 64, isWeapon = true, }
unitTable["armfmkr"] = { radarRadius = 0, techLevel = 1, isBuilding = true, buildTime = 2958, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 409.5, losRadius = 273, wreckName = "", sonarRadius = 0, metalCost = 1, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 2381, mtype = "shp", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armfort"] = { radarRadius = 0, techLevel = 5, isBuilding = true, buildTime = 1065, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 1.5, losRadius = 1, wreckName = "armfort_rockteethx", sonarRadius = 0, metalCost = 39, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 1063, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armfrad"] = { radarRadius = 2100, techLevel = 1, isBuilding = true, buildTime = 1637, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 1140, losRadius = 760, wreckName = "armfrad_dead", sonarRadius = 0, metalCost = 135, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 1051, mtype = "shp", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armfrt"] = { radarRadius = 0, techLevel = 1, isBuilding = true, buildTime = 2163, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 750, losRadius = 468, wreckName = "armfrt_dead", sonarRadius = 0, metalCost = 91, xsize = 8, submergedRange = 0, jammerRadius = 0, zsize = 8, energyCost = 1053, mtype = "shp", airRange = 765, totalEnergyOut = -0.1, stealth = false, groundRange = 0, isWeapon = true, }
unitTable["armfus"] = { radarRadius = 0, techLevel = 5, isBuilding = true, buildTime = 70014, needsWater = false, extractsMetal = 0, bigExplosion = true, airLosRadius = 409.5, losRadius = 273, wreckName = "armfus_dead", sonarRadius = 0, metalCost = 4271, xsize = 10, submergedRange = 0, jammerRadius = 0, zsize = 8, energyCost = 21169, mtype = "veh", airRange = 0, totalEnergyOut = 1000, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armgate"] = { radarRadius = 0, techLevel = 5, isBuilding = true, buildTime = 54139, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 409.5, losRadius = 273, wreckName = "armgate_dead", sonarRadius = 0, metalCost = 3767, xsize = 8, submergedRange = 0, jammerRadius = 0, zsize = 8, energyCost = 66337, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 500, isWeapon = false, }
unitTable["armgeo"] = { radarRadius = 0, techLevel = 3, isBuilding = true, buildTime = 13078, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 409.5, losRadius = 273, wreckName = "armgeo_dead", sonarRadius = 0, metalCost = 555, xsize = 8, submergedRange = 0, jammerRadius = 0, zsize = 8, energyCost = 13406, mtype = "veh", airRange = 0, totalEnergyOut = 300, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armgmm"] = { radarRadius = 0, techLevel = 5, isBuilding = true, buildTime = 41347, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 409.5, losRadius = 273, wreckName = "", sonarRadius = 0, metalCost = 1129, xsize = 10, submergedRange = 0, jammerRadius = 0, zsize = 10, energyCost = 25845, mtype = "veh", airRange = 0, totalEnergyOut = 750, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armguard"] = { radarRadius = 0, techLevel = 3, isBuilding = true, buildTime = 21377, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 682.5, losRadius = 455, wreckName = "armguard_dead", sonarRadius = 0, metalCost = 1491, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 12466, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 1220, isWeapon = true, }
unitTable["armham"] = { radarRadius = 0, techLevel = 2, isBuilding = false, buildTime = 2210, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 570, losRadius = 380, wreckName = "armham_dead", sonarRadius = 0, metalCost = 129, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 1313, mtype = "bot", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 380, isWeapon = true, }
unitTable["armhawk"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 7685, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 800, losRadius = 200, wreckName = "", sonarRadius = 0, metalCost = 122, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 4899, mtype = "air", airRange = 562, totalEnergyOut = 0, stealth = true, groundRange = 562, isWeapon = true, }
unitTable["armhlt"] = { radarRadius = 0, techLevel = 3, isBuilding = true, buildTime = 12500, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 741, losRadius = 494, wreckName = "armhlt_dead", sonarRadius = 0, metalCost = 442, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 4691, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 620, isWeapon = true, }
unitTable["armhp"] = { radarRadius = 50, techLevel = 2.5, isBuilding = true, buildTime = 13890, factoriesCanBuild = { }, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 429, wreckName = "armhp_dead", losRadius = 286, zsize = 14, sonarRadius = 0, metalCost = 1019, xsize = 16, submergedRange = 0, jammerRadius = 0, buildOptions = true, energyCost = 4221, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armjam"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 5933, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 450, losRadius = 300, wreckName = "armjam_dead", sonarRadius = 0, metalCost = 103, xsize = 6, submergedRange = 0, jammerRadius = 450, zsize = 6, energyCost = 1729, mtype = "veh", airRange = 0, totalEnergyOut = -84, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armjamt"] = { radarRadius = 0, techLevel = 3, isBuilding = true, buildTime = 9955, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 292.5, losRadius = 195, wreckName = "armjamt_dead", sonarRadius = 0, metalCost = 241, xsize = 4, submergedRange = 0, jammerRadius = 500, zsize = 4, energyCost = 8475, mtype = "veh", airRange = 0, totalEnergyOut = -40, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armjanus"] = { radarRadius = 0, techLevel = 2, isBuilding = false, buildTime = 3545, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 487.5, losRadius = 325, wreckName = "armjanus_dead", sonarRadius = 0, metalCost = 241, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 2518, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 380, isWeapon = true, }
unitTable["armjeth"] = { radarRadius = 0, techLevel = 2, isBuilding = false, buildTime = 1831, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 800, losRadius = 377, wreckName = "armjeth_dead", sonarRadius = 0, metalCost = 123, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 1170, mtype = "bot", airRange = 800, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = true, }
unitTable["armkam"] = { radarRadius = 0, techLevel = 2, isBuilding = false, buildTime = 5046, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 780, losRadius = 520, wreckName = "", sonarRadius = 0, metalCost = 133, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 2374, mtype = "air", airRange = 0, totalEnergyOut = -0.8, stealth = false, groundRange = 350, isWeapon = true, }
unitTable["armlab"] = { radarRadius = 50, techLevel = 1, isBuilding = true, buildTime = 6760, factoriesCanBuild = { }, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 433.5, wreckName = "armlab_dead", losRadius = 289, zsize = 12, sonarRadius = 0, metalCost = 645, xsize = 12, submergedRange = 0, jammerRadius = 0, buildOptions = true, energyCost = 1205, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armlance"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 15096, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 682.5, losRadius = 455, wreckName = "", sonarRadius = 0, metalCost = 326, xsize = 6, submergedRange = 500, jammerRadius = 0, zsize = 6, energyCost = 7038, mtype = "air", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = true, }
unitTable["armlatnk"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 6027, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 585, losRadius = 390, wreckName = "armlatnk_dead", sonarRadius = 0, metalCost = 327, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 6400, mtype = "veh", airRange = 600, totalEnergyOut = 0, stealth = false, groundRange = 320, isWeapon = true, }
unitTable["armllt"] = { radarRadius = 0, techLevel = 1, isBuilding = true, buildTime = 2662, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 741, losRadius = 494, wreckName = "armllt_dead", sonarRadius = 0, metalCost = 86, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 679, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 430, isWeapon = true, }
unitTable["armlun"] = { radarRadius = 0, techLevel = 6, isBuilding = false, buildTime = 98500, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 930, losRadius = 620, wreckName = "armlun_dead", sonarRadius = 550, metalCost = 5787, xsize = 8, submergedRange = 800, jammerRadius = 0, zsize = 8, energyCost = 84841, mtype = "hov", airRange = 0, totalEnergyOut = 0.29999995, stealth = false, groundRange = 800, isWeapon = true, }
unitTable["armmakr"] = { radarRadius = 0, techLevel = 1, isBuilding = true, buildTime = 2605, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 409.5, losRadius = 273, wreckName = "", sonarRadius = 0, metalCost = 1, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 1159, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armmanni"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 25706, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 975, losRadius = 650, wreckName = "armmanni_dead", sonarRadius = 0, metalCost = 1204, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 13309, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 950, isWeapon = true, }
unitTable["armmark"] = { radarRadius = 2200, techLevel = 4, isBuilding = false, buildTime = 3800, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 1350, losRadius = 900, wreckName = "armmark_dead", sonarRadius = 0, metalCost = 101, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 1229, mtype = "bot", airRange = 0, totalEnergyOut = -12, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armmart"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 5530, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 429, losRadius = 286, wreckName = "armmart_dead", sonarRadius = 0, metalCost = 271, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 4096, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 935, isWeapon = true, }
unitTable["armmav"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 18384, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 825, losRadius = 550, wreckName = "armmav_dead", sonarRadius = 0, metalCost = 699, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 12992, mtype = "bot", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 365, isWeapon = true, }
unitTable["armmerl"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 15592, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 370.5, losRadius = 247, wreckName = "armmerl_dead", sonarRadius = 0, metalCost = 919, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 6556, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = true, groundRange = 1215, isWeapon = true, }
unitTable["armmex"] = { radarRadius = 0, techLevel = 1, isBuilding = true, buildTime = 1800, needsWater = false, extractsMetal = 0.001, bigExplosion = false, airLosRadius = 409.5, losRadius = 273, wreckName = "armmex_dead", sonarRadius = 0, metalCost = 53, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 556, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armmh"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 3298, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 763.5, losRadius = 509, wreckName = "armmh_dead", sonarRadius = 0, metalCost = 174, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 3010, mtype = "hov", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 710, isWeapon = true, }
unitTable["armmine1"] = { radarRadius = 0, techLevel = 3, isBuilding = false, buildTime = 50, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 124.799995, losRadius = 83.1999969, wreckName = "", sonarRadius = 0, metalCost = 5, xsize = 2, submergedRange = 0, jammerRadius = 0, zsize = 2, energyCost = 267, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = true, groundRange = 64, isWeapon = true, }
unitTable["armmine2"] = { radarRadius = 0, techLevel = 5, isBuilding = false, buildTime = 100, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 124.799995, losRadius = 83.1999969, wreckName = "", sonarRadius = 0, metalCost = 16, xsize = 2, submergedRange = 0, jammerRadius = 0, zsize = 2, energyCost = 1067, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = true, groundRange = 64, isWeapon = true, }
unitTable["armmine3"] = { radarRadius = 0, techLevel = 3, isBuilding = false, buildTime = 125, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 124.799995, losRadius = 83.1999969, wreckName = "", sonarRadius = 0, metalCost = 21, xsize = 2, submergedRange = 0, jammerRadius = 0, zsize = 2, energyCost = 1333, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = true, groundRange = 64, isWeapon = true, }
unitTable["armmls"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 5247, factoriesCanBuild = { "armsy", "armfhp", "asubpen", }, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 390, wreckName = "armmls_dead", losRadius = 260, zsize = 6, sonarRadius = 0, metalCost = 227, xsize = 6, submergedRange = 0, jammerRadius = 0, buildOptions = true, energyCost = 3973, mtype = "shp", airRange = 0, totalEnergyOut = 4.5, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armmlv"] = { radarRadius = 0, techLevel = 2, isBuilding = false, buildTime = 3519, factoriesCanBuild = { }, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 301.5, wreckName = "armmlv_dead", losRadius = 201, zsize = 4, sonarRadius = 0, metalCost = 57, xsize = 4, submergedRange = 0, jammerRadius = 64, buildOptions = true, energyCost = 1100, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = true, groundRange = 200, isWeapon = false, }
unitTable["armmmkr"] = { radarRadius = 0, techLevel = 5, isBuilding = true, buildTime = 34980, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 409.5, losRadius = 273, wreckName = "armmmkr_dead", sonarRadius = 0, metalCost = 382, xsize = 8, submergedRange = 0, jammerRadius = 0, zsize = 8, energyCost = 20640, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armmoho"] = { radarRadius = 0, techLevel = 5, isBuilding = true, buildTime = 14938, needsWater = false, extractsMetal = 0.004, bigExplosion = false, airLosRadius = 409.5, losRadius = 273, wreckName = "armmoho_dead", sonarRadius = 0, metalCost = 621, xsize = 10, submergedRange = 0, jammerRadius = 0, zsize = 10, energyCost = 7695, mtype = "veh", airRange = 0, totalEnergyOut = -25, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armmship"] = { radarRadius = 1400, techLevel = 4, isBuilding = false, buildTime = 24817, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 477.75, losRadius = 318.5, wreckName = "armmship_dead", sonarRadius = 0, metalCost = 2825, xsize = 8, submergedRange = 0, jammerRadius = 0, zsize = 8, energyCost = 18060, mtype = "shp", airRange = 1550, totalEnergyOut = 4.5, stealth = false, groundRange = 1550, isWeapon = true, }
unitTable["armmstor"] = { radarRadius = 0, techLevel = 1, isBuilding = true, buildTime = 2925, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 409.5, losRadius = 273, wreckName = "armmstor_dead", sonarRadius = 0, metalCost = 325, xsize = 8, submergedRange = 0, jammerRadius = 0, zsize = 8, energyCost = 571, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armnanotc"] = { radarRadius = 0, techLevel = 3, isBuilding = false, buildTime = 5312, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 570, losRadius = 380, wreckName = "", sonarRadius = 0, metalCost = 210, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 3222, mtype = "veh", airRange = 0, totalEnergyOut = -30, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armorco"] = { radarRadius = 0, techLevel = -1, isBuilding = false, buildTime = 499801, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 1365, losRadius = 910, wreckName = "armorco_dead", sonarRadius = 0, metalCost = 37831, xsize = 10, submergedRange = 0, jammerRadius = 0, zsize = 10, energyCost = 631421, mtype = "bot", airRange = 775, totalEnergyOut = 40, stealth = false, groundRange = 925, isWeapon = true, }
unitTable["armpb"] = { radarRadius = 0, techLevel = 5, isBuilding = true, buildTime = 14961, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 897, losRadius = 598, wreckName = "armpb_dead", sonarRadius = 0, metalCost = 681, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 13756, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 730, isWeapon = true, }
unitTable["armpeep"] = { radarRadius = 1140, techLevel = 2, isBuilding = false, buildTime = 2585, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 1297.5, losRadius = 865, wreckName = "", sonarRadius = 0, metalCost = 52, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 1573, mtype = "air", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armpincer"] = { radarRadius = 0, techLevel = 2, isBuilding = false, buildTime = 2613, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 360, losRadius = 240, wreckName = "armpincer_dead", sonarRadius = 0, metalCost = 199, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 2049, mtype = "amp", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 305, isWeapon = true, }
unitTable["armplat"] = { radarRadius = 50, techLevel = 3, isBuilding = true, buildTime = 16128, factoriesCanBuild = { }, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 253.5, wreckName = "armplat_dead", losRadius = 169, zsize = 14, sonarRadius = 0, metalCost = 1684, xsize = 14, submergedRange = 0, jammerRadius = 0, buildOptions = true, energyCost = 18369, mtype = "shp", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armpnix"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 22064, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 390, losRadius = 260, wreckName = "", sonarRadius = 0, metalCost = 231, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 16082, mtype = "air", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 1280, isWeapon = true, }
unitTable["armpt"] = { radarRadius = 0, techLevel = 2, isBuilding = false, buildTime = 2062, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 800, losRadius = 650, wreckName = "armpt_dead", sonarRadius = 0, metalCost = 107, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 1051, mtype = "shp", airRange = 760, totalEnergyOut = 4.5, stealth = false, groundRange = 260, isWeapon = true, }
unitTable["armptl"] = { radarRadius = 0, techLevel = 1, isBuilding = true, buildTime = 6180, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 450, losRadius = 300, wreckName = "armptl_dead", sonarRadius = 0, metalCost = 322, xsize = 6, submergedRange = 550, jammerRadius = 0, zsize = 6, energyCost = 2195, mtype = "sub", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = true, }
unitTable["armpw"] = { radarRadius = 0, techLevel = 2, isBuilding = false, buildTime = 1420, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 643.5, losRadius = 429, wreckName = "armpw_dead", sonarRadius = 0, metalCost = 48, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 957, mtype = "bot", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 180, isWeapon = true, }
unitTable["armrad"] = { radarRadius = 2100, techLevel = 1, isBuilding = true, buildTime = 1137, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 1020, losRadius = 680, wreckName = "armrad_dead", sonarRadius = 0, metalCost = 58, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 640, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armraven"] = { radarRadius = 0, techLevel = 6, isBuilding = false, buildTime = 126522, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 1050, losRadius = 700, wreckName = "armraven_dead", sonarRadius = 0, metalCost = 4854, xsize = 8, submergedRange = 0, jammerRadius = 0, zsize = 8, energyCost = 80667, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 1350, isWeapon = true, }
unitTable["armraz"] = { radarRadius = 0, techLevel = 6, isBuilding = false, buildTime = 88566, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 675, losRadius = 450, wreckName = "armraz_dead", sonarRadius = 0, metalCost = 3815, xsize = 8, submergedRange = 0, jammerRadius = 0, zsize = 8, energyCost = 67505, mtype = "bot", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 475, isWeapon = true, }
unitTable["armrecl"] = { radarRadius = 0, techLevel = 2, isBuilding = false, buildTime = 7407, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 645, losRadius = 430, wreckName = "", sonarRadius = 270, metalCost = 418, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 4423, mtype = "sub", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armrectr"] = { radarRadius = 50, techLevel = 2, isBuilding = false, buildTime = 2400, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 645, losRadius = 430, wreckName = "armrectr_dead", sonarRadius = 0, metalCost = 109, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 1493, mtype = "bot", airRange = 0, totalEnergyOut = 0, stealth = true, groundRange = 0, isWeapon = false, }
unitTable["armrl"] = { radarRadius = 0, techLevel = 1, isBuilding = true, buildTime = 1843, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 700, losRadius = 455, wreckName = "armrl_dead", sonarRadius = 0, metalCost = 84, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 899, mtype = "veh", airRange = 765, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = true, }
unitTable["armrock"] = { radarRadius = 0, techLevel = 2, isBuilding = false, buildTime = 2015, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 507, losRadius = 338, wreckName = "armrock_dead", sonarRadius = 0, metalCost = 119, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 1056, mtype = "bot", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 475, isWeapon = true, }
unitTable["armroy"] = { radarRadius = 0, techLevel = 2, isBuilding = false, buildTime = 13391, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 735, losRadius = 490, wreckName = "armroy_dead", sonarRadius = 400, metalCost = 1053, xsize = 6, submergedRange = 400, jammerRadius = 0, zsize = 6, energyCost = 6049, mtype = "shp", airRange = 0, totalEnergyOut = 4.5, stealth = false, groundRange = 700, isWeapon = true, }
unitTable["armsaber"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 9016, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 892.5, losRadius = 595, wreckName = "", sonarRadius = 0, metalCost = 214, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 6383, mtype = "air", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 475, isWeapon = true, }
unitTable["armsam"] = { radarRadius = 0, techLevel = 2, isBuilding = false, buildTime = 3415, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 900, losRadius = 620, wreckName = "armsam_dead", sonarRadius = 0, metalCost = 149, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 2162, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 600, isWeapon = true, }
unitTable["armsb"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 27684, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 682.5, losRadius = 455, wreckName = "", sonarRadius = 0, metalCost = 313, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 30414, mtype = "air", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 1280, isWeapon = true, }
unitTable["armscab"] = { radarRadius = 50, techLevel = 4, isBuilding = false, buildTime = 40000, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 675, losRadius = 450, wreckName = "armscab_dead", sonarRadius = 0, metalCost = 1173, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 29867, mtype = "veh", airRange = 0, totalEnergyOut = 200, stealth = false, groundRange = 72000, isWeapon = true, }
unitTable["armsd"] = { radarRadius = 0, techLevel = 5, isBuilding = true, buildTime = 11877, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 360, losRadius = 240, wreckName = "armsd_dead", sonarRadius = 0, metalCost = 705, xsize = 8, submergedRange = 0, jammerRadius = 0, zsize = 8, energyCost = 7188, mtype = "veh", airRange = 0, totalEnergyOut = -125, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armseap"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 14825, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 682.5, losRadius = 455, wreckName = "", sonarRadius = 0, metalCost = 291, xsize = 6, submergedRange = 660, jammerRadius = 0, zsize = 6, energyCost = 6527, mtype = "air", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = true, }
unitTable["armseer"] = { radarRadius = 2300, techLevel = 4, isBuilding = false, buildTime = 6186, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 1350, losRadius = 900, wreckName = "armseer_dead", sonarRadius = 0, metalCost = 123, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 2070, mtype = "veh", airRange = 0, totalEnergyOut = -12, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armsehak"] = { radarRadius = 2250, techLevel = 4, isBuilding = false, buildTime = 9064, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 1650, losRadius = 1100, wreckName = "", sonarRadius = 900, metalCost = 127, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 7066, mtype = "air", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armsfig"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 7279, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 700, losRadius = 200, wreckName = "", sonarRadius = 0, metalCost = 77, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 4559, mtype = "air", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 550, isWeapon = true, }
unitTable["armsh"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 3896, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 873, losRadius = 582, wreckName = "armsh_dead", sonarRadius = 0, metalCost = 93, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 1434, mtype = "hov", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 230, isWeapon = true, }
unitTable["armshltx"] = { radarRadius = 0, techLevel = 5, isBuilding = true, buildTime = 61380, factoriesCanBuild = { }, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 409.5, wreckName = "armshltx_armshlt_dead", losRadius = 273, zsize = 18, sonarRadius = 0, metalCost = 7889, xsize = 18, submergedRange = 0, jammerRadius = 0, buildOptions = true, energyCost = 58176, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armshltxuw"] = { radarRadius = 0, techLevel = 5, isBuilding = true, buildTime = 61380, factoriesCanBuild = { }, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 409.5, wreckName = "armshltxuw_armshlt_dead", losRadius = 273, zsize = 18, sonarRadius = 0, metalCost = 7889, xsize = 18, submergedRange = 0, jammerRadius = 0, buildOptions = true, energyCost = 58176, mtype = "sub", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armshock"] = { radarRadius = 0, techLevel = 6, isBuilding = false, buildTime = 101218, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 937.5, losRadius = 625, wreckName = "armshock_dead", sonarRadius = 0, metalCost = 3328, xsize = 8, submergedRange = 0, jammerRadius = 0, zsize = 8, energyCost = 70066, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 1325, isWeapon = true, }
unitTable["armsilo"] = { radarRadius = 50, techLevel = 5, isBuilding = true, buildTime = 178453, needsWater = false, extractsMetal = 0, bigExplosion = true, airLosRadius = 682.5, losRadius = 455, wreckName = "armsilo_dead", sonarRadius = 0, metalCost = 8133, xsize = 14, submergedRange = 0, jammerRadius = 0, zsize = 14, energyCost = 89886, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 72000, isWeapon = true, }
unitTable["armsjam"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 6708, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 585, losRadius = 390, wreckName = "armsjam_dead", sonarRadius = 0, metalCost = 140, xsize = 6, submergedRange = 0, jammerRadius = 980, zsize = 6, energyCost = 2057, mtype = "shp", airRange = 0, totalEnergyOut = 4.5, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armsl"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 15289, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 390, losRadius = 260, wreckName = "", sonarRadius = 0, metalCost = 367, xsize = 8, submergedRange = 0, jammerRadius = 0, zsize = 8, energyCost = 6497, mtype = "air", airRange = 0, totalEnergyOut = 3, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armsnipe"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 19137, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 682.5, losRadius = 455, wreckName = "armsnipe_dead", sonarRadius = 0, metalCost = 683, xsize = 4, submergedRange = 0, jammerRadius = 10, zsize = 4, energyCost = 19636, mtype = "bot", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 900, isWeapon = true, }
unitTable["armsolar"] = { radarRadius = 0, techLevel = 1, isBuilding = true, buildTime = 2845, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 409.5, losRadius = 273, wreckName = "armsolar_dead", sonarRadius = 0, metalCost = 155, xsize = 10, submergedRange = 0, jammerRadius = 0, zsize = 10, energyCost = 0, mtype = "veh", airRange = 0, totalEnergyOut = 20, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armsonar"] = { radarRadius = 0, techLevel = 1, isBuilding = true, buildTime = 912, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 772.5, losRadius = 515, wreckName = "armsonar_dead", sonarRadius = 1200, metalCost = 21, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 430, mtype = "sub", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armspid"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 5090, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 825, losRadius = 550, wreckName = "armspid_dead", sonarRadius = 0, metalCost = 177, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 3381, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = true, groundRange = 280, isWeapon = true, }
unitTable["armsptk"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 8775, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 660, losRadius = 440, wreckName = "armsptk_dead", sonarRadius = 0, metalCost = 400, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 4480, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 550, isWeapon = true, }
unitTable["armspy"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 17631, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 825, losRadius = 550, wreckName = "armspy_dead", sonarRadius = 0, metalCost = 137, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 8767, mtype = "bot", airRange = 0, totalEnergyOut = 0, stealth = true, groundRange = 0, isWeapon = false, }
unitTable["armst"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 6704, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 741, losRadius = 494, wreckName = "armst_dead", sonarRadius = 0, metalCost = 226, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 3712, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = true, groundRange = 220, isWeapon = true, }
unitTable["armstump"] = { radarRadius = 0, techLevel = 2, isBuilding = false, buildTime = 2904, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 487.5, losRadius = 325, wreckName = "armstump_dead", sonarRadius = 0, metalCost = 214, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 2049, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 350, isWeapon = true, }
unitTable["armsub"] = { radarRadius = 0, techLevel = 2, isBuilding = false, buildTime = 10983, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 600, losRadius = 400, wreckName = "armsub_dead", sonarRadius = 475, metalCost = 694, xsize = 4, submergedRange = 500, jammerRadius = 0, zsize = 4, energyCost = 3972, mtype = "sub", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = true, }
unitTable["armsubk"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 17767, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 585, losRadius = 390, wreckName = "armsubk_dead", sonarRadius = 525, metalCost = 1118, xsize = 6, submergedRange = 600, jammerRadius = 0, zsize = 6, energyCost = 10113, mtype = "sub", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = true, }
unitTable["armsy"] = { radarRadius = 50, techLevel = 1, isBuilding = true, buildTime = 6050, factoriesCanBuild = { }, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 510, wreckName = "armsy_dead", losRadius = 340, zsize = 16, sonarRadius = 0, metalCost = 453, xsize = 16, submergedRange = 0, jammerRadius = 0, buildOptions = true, energyCost = 827, mtype = "shp", airRange = 0, totalEnergyOut = 15, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armtarg"] = { radarRadius = 0, techLevel = 5, isBuilding = true, buildTime = 8707, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 409.5, losRadius = 273, wreckName = "armtarg_dead", sonarRadius = 0, metalCost = 807, xsize = 8, submergedRange = 0, jammerRadius = 0, zsize = 8, energyCost = 7255, mtype = "veh", airRange = 0, totalEnergyOut = -100, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armthovr"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 20341, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 487.5, losRadius = 325, wreckName = "armthovr_dead", sonarRadius = 0, metalCost = 709, xsize = 8, submergedRange = 0, jammerRadius = 0, zsize = 8, energyCost = 8467, mtype = "hov", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = true, }
unitTable["armthund"] = { radarRadius = 0, techLevel = 2, isBuilding = false, buildTime = 4778, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 292.5, losRadius = 195, wreckName = "", sonarRadius = 0, metalCost = 147, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 4129, mtype = "air", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 1280, isWeapon = true, }
unitTable["armtide"] = { radarRadius = 0, techLevel = 1, isBuilding = true, buildTime = 2188, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 195, losRadius = 130, wreckName = "armtide_dead", sonarRadius = 0, metalCost = 87, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 307, mtype = "shp", airRange = 0, totalEnergyOut = 10, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armtl"] = { radarRadius = 0, techLevel = 3, isBuilding = true, buildTime = 8240, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 682.5, losRadius = 455, wreckName = "armtl_dead", sonarRadius = 0, metalCost = 322, xsize = 6, submergedRange = 550, jammerRadius = 0, zsize = 6, energyCost = 2195, mtype = "shp", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = true, }
unitTable["armtship"] = { radarRadius = 0, techLevel = 2, isBuilding = false, buildTime = 10176, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 825, losRadius = 550, wreckName = "armtship_dead", sonarRadius = 0, metalCost = 784, xsize = 8, submergedRange = 0, jammerRadius = 0, zsize = 8, energyCost = 6655, mtype = "shp", airRange = 0, totalEnergyOut = 4.5, stealth = false, groundRange = 0, isWeapon = true, }
unitTable["armuwadves"] = { radarRadius = 0, techLevel = 5, isBuilding = true, buildTime = 20302, needsWater = false, extractsMetal = 0, bigExplosion = true, airLosRadius = 253.5, losRadius = 169, wreckName = "armuwadves_dead", sonarRadius = 0, metalCost = 825, xsize = 8, submergedRange = 0, jammerRadius = 0, zsize = 8, energyCost = 10767, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armuwadvms"] = { radarRadius = 0, techLevel = 5, isBuilding = true, buildTime = 20391, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 292.5, losRadius = 195, wreckName = "armuwadvms_dead", sonarRadius = 0, metalCost = 752, xsize = 8, submergedRange = 0, jammerRadius = 0, zsize = 8, energyCost = 11193, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armuwes"] = { radarRadius = 0, techLevel = 1, isBuilding = true, buildTime = 7085, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 273, losRadius = 182, wreckName = "armuwes_dead", sonarRadius = 0, metalCost = 303, xsize = 8, submergedRange = 0, jammerRadius = 0, zsize = 8, energyCost = 2608, mtype = "sub", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armuwfus"] = { radarRadius = 0, techLevel = 5, isBuilding = true, buildTime = 99870, needsWater = true, extractsMetal = 0, bigExplosion = true, airLosRadius = 214.5, losRadius = 143, wreckName = "armuwfus_dead", sonarRadius = 0, metalCost = 5235, xsize = 10, submergedRange = 0, jammerRadius = 0, zsize = 8, energyCost = 33524, mtype = "sub", airRange = 0, totalEnergyOut = 1200, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armuwmex"] = { radarRadius = 0, techLevel = 1, isBuilding = true, buildTime = 1875, needsWater = true, extractsMetal = 0.001, bigExplosion = false, airLosRadius = 273, losRadius = 182, wreckName = "armuwmex_dead", sonarRadius = 0, metalCost = 59, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 719, mtype = "sub", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armuwmme"] = { radarRadius = 0, techLevel = 5, isBuilding = true, buildTime = 35370, needsWater = true, extractsMetal = 0.004, bigExplosion = false, airLosRadius = 273, losRadius = 182, wreckName = "armuwmme_dead", sonarRadius = 0, metalCost = 641, xsize = 10, submergedRange = 0, jammerRadius = 0, zsize = 10, energyCost = 9775, mtype = "sub", airRange = 0, totalEnergyOut = -25, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armuwmmm"] = { radarRadius = 0, techLevel = 5, isBuilding = true, buildTime = 38964, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 234, losRadius = 156, wreckName = "armuwmmm_dead", sonarRadius = 0, metalCost = 397, xsize = 10, submergedRange = 0, jammerRadius = 0, zsize = 8, energyCost = 23494, mtype = "shp", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armuwms"] = { radarRadius = 0, techLevel = 1, isBuilding = true, buildTime = 3741, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 273, losRadius = 182, wreckName = "armuwms_dead", sonarRadius = 0, metalCost = 384, xsize = 8, submergedRange = 0, jammerRadius = 0, zsize = 8, energyCost = 1339, mtype = "sub", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armvader"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 7901, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 409.5, losRadius = 273, wreckName = "armvader_corpse", sonarRadius = 0, metalCost = 65, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 5838, mtype = "bot", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 80, isWeapon = true, }
unitTable["armveil"] = { radarRadius = 0, techLevel = 5, isBuilding = true, buildTime = 9080, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 232.5, losRadius = 155, wreckName = "armveil_dead", sonarRadius = 0, metalCost = 127, xsize = 4, submergedRange = 0, jammerRadius = 760, zsize = 4, energyCost = 18668, mtype = "veh", airRange = 0, totalEnergyOut = -125, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armvp"] = { radarRadius = 50, techLevel = 1, isBuilding = true, buildTime = 7192, factoriesCanBuild = { }, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 409.5, wreckName = "armvp_dead", losRadius = 273, zsize = 12, sonarRadius = 0, metalCost = 793, xsize = 16, submergedRange = 0, jammerRadius = 0, buildOptions = true, energyCost = 1977, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armvulc"] = { radarRadius = 0, techLevel = 5, isBuilding = true, buildTime = 1009441, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 1050, losRadius = 700, wreckName = "armvulc_dead", sonarRadius = 0, metalCost = 45187, xsize = 16, submergedRange = 0, jammerRadius = 0, zsize = 16, energyCost = 537220, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 5750, isWeapon = true, }
unitTable["armwar"] = { radarRadius = 0, techLevel = 2, isBuilding = false, buildTime = 3828, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 525, losRadius = 350, wreckName = "armwar_dead", sonarRadius = 0, metalCost = 265, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 3140, mtype = "bot", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 330, isWeapon = true, }
unitTable["armwin"] = { radarRadius = 0, techLevel = 1, isBuilding = true, buildTime = 1603, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 409.5, losRadius = 273, wreckName = "armwin_dead", sonarRadius = 0, metalCost = 37, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 173, mtype = "veh", airRange = 0, totalEnergyOut = 4.5, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["armyork"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 9964, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 900, losRadius = 390, wreckName = "armyork_dead", sonarRadius = 0, metalCost = 453, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 9077, mtype = "veh", airRange = 800, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = true, }
unitTable["armzeus"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 7252, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 497.25, losRadius = 331.5, wreckName = "armzeus_dead", sonarRadius = 0, metalCost = 351, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 6046, mtype = "bot", airRange = 0, totalEnergyOut = 3.5, stealth = false, groundRange = 280, isWeapon = true, }
unitTable["aseadragon"] = { radarRadius = 1530, techLevel = 4, isBuilding = false, buildTime = 299523, needsWater = true, extractsMetal = 0, bigExplosion = true, airLosRadius = 1033.5, losRadius = 689, wreckName = "aseadragon_dead", sonarRadius = 0, metalCost = 34263, xsize = 12, submergedRange = 0, jammerRadius = 0, zsize = 12, energyCost = 254300, mtype = "shp", airRange = 775, totalEnergyOut = 4.5, stealth = false, groundRange = 2450, isWeapon = true, }
unitTable["asubpen"] = { radarRadius = 0, techLevel = 3, isBuilding = true, buildTime = 11112, factoriesCanBuild = { }, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 351, wreckName = "asubpen_dead", losRadius = 234, zsize = 16, sonarRadius = 0, metalCost = 1193, xsize = 16, submergedRange = 0, jammerRadius = 0, buildOptions = true, energyCost = 5487, mtype = "sub", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["blade"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 23964, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 936, losRadius = 624, wreckName = "", sonarRadius = 0, metalCost = 1271, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 21669, mtype = "air", airRange = 0, totalEnergyOut = -0.1, stealth = false, groundRange = 420, isWeapon = true, }
unitTable["bladew"] = { radarRadius = 0, techLevel = 2, isBuilding = false, buildTime = 2073, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 546, losRadius = 364, wreckName = "", sonarRadius = 0, metalCost = 58, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 1280, mtype = "air", airRange = 0, totalEnergyOut = 2, stealth = false, groundRange = 220, isWeapon = true, }
unitTable["cafus"] = { radarRadius = 0, techLevel = 5, isBuilding = true, buildTime = 329243, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 409.5, losRadius = 273, wreckName = "cafus_dead", sonarRadius = 0, metalCost = 9714, xsize = 12, submergedRange = 0, jammerRadius = 0, zsize = 12, energyCost = 47712, mtype = "veh", airRange = 0, totalEnergyOut = 3000, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["cjuno"] = { radarRadius = 0, techLevel = 3, isBuilding = true, buildTime = 27681, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 741, losRadius = 494, wreckName = "cjuno_dead", sonarRadius = 0, metalCost = 658, xsize = 8, submergedRange = 0, jammerRadius = 0, zsize = 8, energyCost = 16132, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = true, groundRange = 32000, isWeapon = true, }
unitTable["cmgeo"] = { radarRadius = 0, techLevel = 5, isBuilding = true, buildTime = 32078, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 409.5, losRadius = 273, wreckName = "", sonarRadius = 0, metalCost = 1515, xsize = 14, submergedRange = 0, jammerRadius = 0, zsize = 10, energyCost = 26206, mtype = "veh", airRange = 0, totalEnergyOut = 1250, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["commando"] = { radarRadius = 900, techLevel = 4, isBuilding = false, buildTime = 17131, factoriesCanBuild = { }, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 900, wreckName = "", losRadius = 600, zsize = 4, sonarRadius = 0, metalCost = 1201, xsize = 4, submergedRange = 0, jammerRadius = 150, buildOptions = true, energyCost = 15309, mtype = "veh", airRange = 0, totalEnergyOut = 10, stealth = false, groundRange = 310, isWeapon = true, }
unitTable["consul"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 6793, factoriesCanBuild = { "armvp", }, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 750, wreckName = "consul_dead", losRadius = 500, zsize = 6, sonarRadius = 0, metalCost = 252, xsize = 6, submergedRange = 0, jammerRadius = 0, buildOptions = true, energyCost = 4297, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["coraak"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 7581, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 925, losRadius = 390, wreckName = "coraak_dead", sonarRadius = 0, metalCost = 649, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 6202, mtype = "bot", airRange = 850, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = true, }
unitTable["coraap"] = { radarRadius = 0, techLevel = 3, isBuilding = true, buildTime = 20678, factoriesCanBuild = { }, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 458.25, wreckName = "coraap_dead", losRadius = 305.5, zsize = 12, sonarRadius = 0, metalCost = 3178, xsize = 16, submergedRange = 0, jammerRadius = 0, buildOptions = true, energyCost = 28342, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["coraca"] = { radarRadius = 50, techLevel = 4, isBuilding = false, buildTime = 18001, factoriesCanBuild = { "corap", "coraap", "corplat", }, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 575.25, wreckName = "", losRadius = 383.5, zsize = 4, sonarRadius = 0, metalCost = 295, xsize = 4, submergedRange = 0, jammerRadius = 0, buildOptions = true, energyCost = 11294, mtype = "air", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["corack"] = { radarRadius = 50, techLevel = 4, isBuilding = false, buildTime = 9709, factoriesCanBuild = { "corgant", "corlab", "coralab", }, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 477.75, wreckName = "corack_dead", losRadius = 318.5, zsize = 4, sonarRadius = 0, metalCost = 408, xsize = 4, submergedRange = 0, jammerRadius = 0, buildOptions = true, energyCost = 6948, mtype = "bot", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["coracsub"] = { radarRadius = 50, techLevel = 4, isBuilding = false, buildTime = 24205, factoriesCanBuild = { "corplat", "corsy", "corasy", "corgantuw", "csubpen", }, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 234, wreckName = "coracsub_dead", losRadius = 156, zsize = 6, sonarRadius = 0, metalCost = 844, xsize = 6, submergedRange = 0, jammerRadius = 0, buildOptions = true, energyCost = 11638, mtype = "sub", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["coracv"] = { radarRadius = 50, techLevel = 4, isBuilding = false, buildTime = 12882, factoriesCanBuild = { "corvp", "coravp", }, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 442.650024, wreckName = "coracv_dead", losRadius = 295.100006, zsize = 6, sonarRadius = 0, metalCost = 578, xsize = 6, submergedRange = 0, jammerRadius = 0, buildOptions = true, energyCost = 7054, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["coradvsol"] = { radarRadius = 0, techLevel = 3, isBuilding = true, buildTime = 8143, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 390, losRadius = 260, wreckName = "coradvsol_dead", sonarRadius = 0, metalCost = 371, xsize = 8, submergedRange = 0, jammerRadius = 0, zsize = 8, energyCost = 3950, mtype = "veh", airRange = 0, totalEnergyOut = 75, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["corah"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 3652, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 800, losRadius = 509, wreckName = "corah_dead", sonarRadius = 350, metalCost = 253, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 4745, mtype = "hov", airRange = 800, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = true, }
unitTable["corak"] = { radarRadius = 0, techLevel = 2, isBuilding = false, buildTime = 1279, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 750, losRadius = 500, wreckName = "corak_dead", sonarRadius = 0, metalCost = 36, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 881, mtype = "bot", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 240, isWeapon = true, }
unitTable["coralab"] = { radarRadius = 50, techLevel = 3, isBuilding = true, buildTime = 16819, factoriesCanBuild = { }, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 432.900024, wreckName = "coralab_dead", losRadius = 288.600006, zsize = 12, sonarRadius = 0, metalCost = 2860, xsize = 14, submergedRange = 0, jammerRadius = 0, buildOptions = true, energyCost = 16247, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["coramph"] = { radarRadius = 300, techLevel = 4, isBuilding = false, buildTime = 9650, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 600, losRadius = 400, wreckName = "coramph_heap", sonarRadius = 300, metalCost = 325, xsize = 4, submergedRange = 400, jammerRadius = 0, zsize = 4, energyCost = 9531, mtype = "bot", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 300, isWeapon = true, }
unitTable["corap"] = { radarRadius = 510, techLevel = 1, isBuilding = true, buildTime = 7180, factoriesCanBuild = { }, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 409.5, wreckName = "corap_dead", losRadius = 273, zsize = 12, sonarRadius = 0, metalCost = 885, xsize = 16, submergedRange = 0, jammerRadius = 0, buildOptions = true, energyCost = 1429, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["corape"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 14500, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 825, losRadius = 550, wreckName = "", sonarRadius = 0, metalCost = 368, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 6898, mtype = "air", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 410, isWeapon = true, }
unitTable["corarad"] = { radarRadius = 3500, techLevel = 5, isBuilding = true, buildTime = 11960, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 1170, losRadius = 780, wreckName = "corarad_dead", sonarRadius = 0, metalCost = 557, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 19115, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["corarch"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 9791, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 900, losRadius = 465, wreckName = "corarch_dead", sonarRadius = 0, metalCost = 655, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 8449, mtype = "shp", airRange = 840, totalEnergyOut = 4.5, stealth = false, groundRange = 0, isWeapon = true, }
unitTable["corason"] = { radarRadius = 0, techLevel = 5, isBuilding = true, buildTime = 6096, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 315, losRadius = 210, wreckName = "corason_dead", sonarRadius = 2400, metalCost = 162, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 2407, mtype = "sub", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["corasp"] = { radarRadius = 0, techLevel = 3, isBuilding = true, buildTime = 9315, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 536.25, losRadius = 357.5, wreckName = "corasp_dead", sonarRadius = 0, metalCost = 403, xsize = 18, submergedRange = 0, jammerRadius = 0, zsize = 18, energyCost = 4311, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["corasy"] = { radarRadius = 50, techLevel = 3, isBuilding = true, buildTime = 15696, factoriesCanBuild = { }, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 452.400024, wreckName = "corasy_dead", losRadius = 301.600006, zsize = 24, sonarRadius = 0, metalCost = 3125, xsize = 24, submergedRange = 0, jammerRadius = 0, buildOptions = true, energyCost = 10414, mtype = "shp", airRange = 0, totalEnergyOut = 25, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["coratl"] = { radarRadius = 0, techLevel = -1, isBuilding = true, buildTime = 7475, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 700, losRadius = 450, wreckName = "coratl_dead", sonarRadius = 0, metalCost = 429, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 4947, mtype = "shp", airRange = 720, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = true, }
unitTable["coravp"] = { radarRadius = 50, techLevel = 3, isBuilding = true, buildTime = 18492, factoriesCanBuild = { }, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 429, wreckName = "coravp_dead", losRadius = 286, zsize = 14, sonarRadius = 0, metalCost = 2823, xsize = 18, submergedRange = 0, jammerRadius = 0, buildOptions = true, energyCost = 15770, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["corawac"] = { radarRadius = 2400, techLevel = 4, isBuilding = false, buildTime = 13264, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 1875, losRadius = 1250, wreckName = "", sonarRadius = 1200, metalCost = 180, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 8346, mtype = "air", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["corbats"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 60640, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 682.5, losRadius = 455, wreckName = "corbats_dead", sonarRadius = 0, metalCost = 5764, xsize = 12, submergedRange = 0, jammerRadius = 0, zsize = 12, energyCost = 23404, mtype = "shp", airRange = 0, totalEnergyOut = 6.5, stealth = false, groundRange = 1320, isWeapon = true, }
unitTable["corbhmth"] = { radarRadius = 0, techLevel = 5, isBuilding = true, buildTime = 59640, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 975, losRadius = 650, wreckName = "corbhmth_dead", sonarRadius = 0, metalCost = 3146, xsize = 10, submergedRange = 0, jammerRadius = 0, zsize = 10, energyCost = 34590, mtype = "veh", airRange = 0, totalEnergyOut = 450, stealth = false, groundRange = 1650, isWeapon = true, }
unitTable["corblackhy"] = { radarRadius = 1510, techLevel = 4, isBuilding = false, buildTime = 309264, needsWater = true, extractsMetal = 0, bigExplosion = true, airLosRadius = 975, losRadius = 650, wreckName = "corblackhy_dead", sonarRadius = 0, metalCost = 36891, xsize = 12, submergedRange = 0, jammerRadius = 0, zsize = 12, energyCost = 269142, mtype = "shp", airRange = 950, totalEnergyOut = -10.5, stealth = false, groundRange = 2450, isWeapon = true, }
unitTable["corbuzz"] = { radarRadius = 0, techLevel = 5, isBuilding = true, buildTime = 1020945, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 1050, losRadius = 700, wreckName = "corbuzz_dead", sonarRadius = 0, metalCost = 43280, xsize = 16, submergedRange = 0, jammerRadius = 0, zsize = 16, energyCost = 513498, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 6100, isWeapon = true, }
unitTable["corca"] = { radarRadius = 50, techLevel = 2, isBuilding = false, buildTime = 9286, factoriesCanBuild = { "coraap", "corlab", "corvp", "corap", "corhp", "corsy", }, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 526.5, wreckName = "", losRadius = 351, zsize = 6, sonarRadius = 0, metalCost = 117, xsize = 6, submergedRange = 0, jammerRadius = 0, buildOptions = true, energyCost = 4885, mtype = "air", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["corcan"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 11734, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 525, losRadius = 350, wreckName = "corcan_dead", sonarRadius = 0, metalCost = 557, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 9303, mtype = "bot", airRange = 0, totalEnergyOut = 7.5, stealth = false, groundRange = 275, isWeapon = true, }
unitTable["corcarry"] = { radarRadius = 2700, techLevel = 4, isBuilding = false, buildTime = 20800, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 1560, losRadius = 1040, wreckName = "corcarry_dead", sonarRadius = 740, metalCost = 1707, xsize = 12, submergedRange = 0, jammerRadius = 0, zsize = 12, energyCost = 22187, mtype = "shp", airRange = 0, totalEnergyOut = 229.5, stealth = false, groundRange = 72000, isWeapon = false, }
unitTable["corch"] = { radarRadius = 50, techLevel = 4, isBuilding = false, buildTime = 4576, factoriesCanBuild = { "corlab", "corvp", "corap", "corhp", "corfhp", "corsy", "csubpen", }, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 507, wreckName = "corch_dead", losRadius = 338, zsize = 6, sonarRadius = 0, metalCost = 164, xsize = 6, submergedRange = 0, jammerRadius = 0, buildOptions = true, energyCost = 2956, mtype = "hov", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["corck"] = { radarRadius = 0, techLevel = 2, isBuilding = false, buildTime = 3551, factoriesCanBuild = { "coralab", "corlab", "corvp", "corap", "corhp", "corsy", }, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 448.5, wreckName = "corck_dead", losRadius = 299, zsize = 4, sonarRadius = 0, metalCost = 121, xsize = 4, submergedRange = 0, jammerRadius = 0, buildOptions = true, energyCost = 1730, mtype = "bot", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["corcom"] = { radarRadius = 700, techLevel = 0, isBuilding = false, buildTime = 75000, factoriesCanBuild = { "corlab", "corvp", "corap", "corsy", }, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 675, wreckName = "corcom_dead", losRadius = 450, zsize = 4, sonarRadius = 450, metalCost = 2667, xsize = 4, submergedRange = 260, jammerRadius = 0, buildOptions = true, energyCost = 26667, mtype = "veh", airRange = 0, totalEnergyOut = 25, stealth = false, groundRange = 300, isWeapon = true, }
unitTable["corcrash"] = { radarRadius = 0, techLevel = 2, isBuilding = false, buildTime = 1900, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 800, losRadius = 379.600006, wreckName = "corcrash_dead", sonarRadius = 0, metalCost = 124, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 1174, mtype = "bot", airRange = 800, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = true, }
unitTable["corcrus"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 19950, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 799.5, losRadius = 533, wreckName = "corcrus_dead", sonarRadius = 375, metalCost = 1914, xsize = 8, submergedRange = 500, jammerRadius = 0, zsize = 8, energyCost = 14454, mtype = "shp", airRange = 0, totalEnergyOut = 4.5, stealth = false, groundRange = 785, isWeapon = true, }
unitTable["corcrw"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 84229, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 741, losRadius = 494, wreckName = "", sonarRadius = 0, metalCost = 5075, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 72627, mtype = "air", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 575, isWeapon = true, }
unitTable["corcs"] = { radarRadius = 0, techLevel = 2, isBuilding = false, buildTime = 8306, factoriesCanBuild = { "corsy", "corasy", "corfhp", "csubpen", "corplat", }, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 429, wreckName = "corcs_dead", losRadius = 286, zsize = 6, sonarRadius = 0, metalCost = 277, xsize = 6, submergedRange = 0, jammerRadius = 0, buildOptions = true, energyCost = 2533, mtype = "shp", airRange = 0, totalEnergyOut = 19.5, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["corcsa"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 20904, factoriesCanBuild = { "corap", "coraap", "corplat", "corsy", "corasy", }, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 526.5, wreckName = "", losRadius = 351, zsize = 4, sonarRadius = 0, metalCost = 273, xsize = 4, submergedRange = 0, jammerRadius = 0, buildOptions = true, energyCost = 25650, mtype = "air", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["corcut"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 9470, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 892.5, losRadius = 595, wreckName = "", sonarRadius = 0, metalCost = 229, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 5437, mtype = "air", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 430, isWeapon = true, }
unitTable["corcv"] = { radarRadius = 50, techLevel = 2, isBuilding = false, buildTime = 4160, factoriesCanBuild = { "coravp", "corlab", "corvp", "corap", "corhp", "corsy", }, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 390, wreckName = "corcv_dead", losRadius = 260, zsize = 6, sonarRadius = 0, metalCost = 143, xsize = 6, submergedRange = 0, jammerRadius = 0, buildOptions = true, energyCost = 2111, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["cordecom"] = { radarRadius = 50, techLevel = 4, isBuilding = false, buildTime = 26941, factoriesCanBuild = { }, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 565.5, wreckName = "", losRadius = 377, zsize = 4, sonarRadius = 0, metalCost = 752, xsize = 4, submergedRange = 0, jammerRadius = 0, buildOptions = true, energyCost = 12891, mtype = "veh", airRange = 0, totalEnergyOut = 15, stealth = false, groundRange = 300, isWeapon = true, }
unitTable["cordl"] = { radarRadius = 0, techLevel = 1, isBuilding = true, buildTime = 4280, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 916.5, losRadius = 611, wreckName = "cordl_dead", sonarRadius = 525, metalCost = 299, xsize = 4, submergedRange = 580, jammerRadius = 0, zsize = 4, energyCost = 2496, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = true, }
unitTable["cordoom"] = { radarRadius = 1200, techLevel = 5, isBuilding = true, buildTime = 55276, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 1170, losRadius = 780, wreckName = "cordoom_dead", sonarRadius = 0, metalCost = 3039, xsize = 8, submergedRange = 0, jammerRadius = 0, zsize = 8, energyCost = 36307, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 950, isWeapon = true, }
unitTable["cordrag"] = { radarRadius = 0, techLevel = 1, isBuilding = true, buildTime = 255, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 1.5, losRadius = 1, wreckName = "cordrag_rockteeth", sonarRadius = 0, metalCost = 11, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 160, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["corenaa"] = { radarRadius = 0, techLevel = 5, isBuilding = true, buildTime = 23129, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 1000, losRadius = 550, wreckName = "corenaa_dead", sonarRadius = 0, metalCost = 887, xsize = 8, submergedRange = 0, jammerRadius = 0, zsize = 8, energyCost = 25327, mtype = "shp", airRange = 775, totalEnergyOut = -0.1, stealth = false, groundRange = 0, isWeapon = true, }
unitTable["corerad"] = { radarRadius = 0, techLevel = 3, isBuilding = true, buildTime = 12958, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 1000, losRadius = 350, wreckName = "corerad_dead", sonarRadius = 0, metalCost = 798, xsize = 8, submergedRange = 0, jammerRadius = 0, zsize = 8, energyCost = 9305, mtype = "veh", airRange = 1045, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = true, }
unitTable["corestor"] = { radarRadius = 0, techLevel = 1, isBuilding = true, buildTime = 4257, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 409.5, losRadius = 273, wreckName = "corestor_dead", sonarRadius = 0, metalCost = 177, xsize = 8, submergedRange = 0, jammerRadius = 0, zsize = 8, energyCost = 1770, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["coresupp"] = { radarRadius = 0, techLevel = 2, isBuilding = false, buildTime = 6660, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 643.5, losRadius = 429, wreckName = "coresupp_dead", sonarRadius = 0, metalCost = 314, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 2447, mtype = "shp", airRange = 0, totalEnergyOut = 7.5, stealth = false, groundRange = 320, isWeapon = true, }
unitTable["coreter"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 6404, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 448.5, losRadius = 299, wreckName = "coreter_dead", sonarRadius = 0, metalCost = 107, xsize = 6, submergedRange = 0, jammerRadius = 450, zsize = 6, energyCost = 1874, mtype = "veh", airRange = 0, totalEnergyOut = -100, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["corexp"] = { radarRadius = 0, techLevel = 3, isBuilding = true, buildTime = 2724, needsWater = false, extractsMetal = 0.001, bigExplosion = false, airLosRadius = 682.5, losRadius = 455, wreckName = "corexp_dead", sonarRadius = 0, metalCost = 235, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 1932, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 430, isWeapon = false, }
unitTable["coreyes"] = { radarRadius = 0, techLevel = 1, isBuilding = true, buildTime = 750, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 810, losRadius = 540, wreckName = "coreyes_cdragonseyes_dead", sonarRadius = 0, metalCost = 32, xsize = 2, submergedRange = 0, jammerRadius = 0, zsize = 2, energyCost = 853, mtype = "veh", airRange = 0, totalEnergyOut = -5, stealth = true, groundRange = 0, isWeapon = false, }
unitTable["corfast"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 6488, factoriesCanBuild = { "corlab", }, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 780, wreckName = "corfast_dead", losRadius = 520, zsize = 4, sonarRadius = 0, metalCost = 205, xsize = 4, submergedRange = 0, jammerRadius = 0, buildOptions = true, energyCost = 3822, mtype = "bot", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["corfatf"] = { radarRadius = 0, techLevel = 5, isBuilding = true, buildTime = 10302, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 409.5, losRadius = 273, wreckName = "corfatf_dead", sonarRadius = 0, metalCost = 799, xsize = 8, submergedRange = 0, jammerRadius = 0, zsize = 8, energyCost = 7552, mtype = "shp", airRange = 0, totalEnergyOut = -150, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["corfav"] = { radarRadius = 0, techLevel = 2, isBuilding = false, buildTime = 1104, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 802.5, losRadius = 535, wreckName = "corfav_dead", sonarRadius = 0, metalCost = 26, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 273, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 180, isWeapon = true, }
unitTable["corfdrag"] = { radarRadius = 0, techLevel = 1, isBuilding = true, buildTime = 1000, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 1.5, losRadius = 1, wreckName = "", sonarRadius = 0, metalCost = 21, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 672, mtype = "shp", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["corfgate"] = { radarRadius = 0, techLevel = -1, isBuilding = false, buildTime = 59060, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 900, losRadius = 600, wreckName = "corfgate_dead", sonarRadius = 0, metalCost = 4097, xsize = 8, submergedRange = 0, jammerRadius = 0, zsize = 8, energyCost = 73949, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 600, isWeapon = false, }
unitTable["corfhlt"] = { radarRadius = 0, techLevel = 3, isBuilding = true, buildTime = 11386, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 918, losRadius = 612, wreckName = "corfhlt_dead", sonarRadius = 0, metalCost = 595, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 6199, mtype = "shp", airRange = 0, totalEnergyOut = 5, stealth = false, groundRange = 620, isWeapon = true, }
unitTable["corfhp"] = { radarRadius = 50, techLevel = 2.5, isBuilding = true, buildTime = 17817, factoriesCanBuild = { }, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 468, wreckName = "corfhp_dead", losRadius = 312, zsize = 14, sonarRadius = 0, metalCost = 1173, xsize = 16, submergedRange = 0, jammerRadius = 0, buildOptions = true, energyCost = 5421, mtype = "shp", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["corfink"] = { radarRadius = 1120, techLevel = 2, isBuilding = false, buildTime = 2156, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 1252.5, losRadius = 835, wreckName = "", sonarRadius = 0, metalCost = 51, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 1460, mtype = "air", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["corflak"] = { radarRadius = 0, techLevel = 5, isBuilding = true, buildTime = 20112, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 1000, losRadius = 525, wreckName = "corflak_dead", sonarRadius = 0, metalCost = 845, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 14183, mtype = "veh", airRange = 775, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = true, }
unitTable["corfmd"] = { radarRadius = 50, techLevel = 5, isBuilding = true, buildTime = 60000, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 292.5, losRadius = 195, wreckName = "corfmd_dead", sonarRadius = 0, metalCost = 1493, xsize = 8, submergedRange = 0, jammerRadius = 0, zsize = 8, energyCost = 40320, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 72000, isWeapon = true, }
unitTable["corfmine3"] = { radarRadius = 0, techLevel = 5, isBuilding = false, buildTime = 150, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 107.25, losRadius = 71.5, wreckName = "", sonarRadius = 0, metalCost = 27, xsize = 2, submergedRange = 0, jammerRadius = 0, zsize = 2, energyCost = 1600, mtype = "hov", airRange = 0, totalEnergyOut = 0, stealth = true, groundRange = 64, isWeapon = true, }
unitTable["corfmkr"] = { radarRadius = 0, techLevel = 1, isBuilding = true, buildTime = 2682, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 409.5, losRadius = 273, wreckName = "", sonarRadius = 0, metalCost = 1, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 2429, mtype = "shp", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["corfort"] = { radarRadius = 0, techLevel = 5, isBuilding = true, buildTime = 1010, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 1.5, losRadius = 1, wreckName = "corfort_rockteethx", sonarRadius = 0, metalCost = 38, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 1098, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["corfrad"] = { radarRadius = 2100, techLevel = 1, isBuilding = true, buildTime = 1783, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 1110, losRadius = 740, wreckName = "corfrad_dead", sonarRadius = 0, metalCost = 131, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 1124, mtype = "shp", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["corfrt"] = { radarRadius = 0, techLevel = 1, isBuilding = true, buildTime = 2357, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 750, losRadius = 468, wreckName = "corfrt_dead", sonarRadius = 0, metalCost = 92, xsize = 8, submergedRange = 0, jammerRadius = 0, zsize = 8, energyCost = 1124, mtype = "shp", airRange = 765, totalEnergyOut = -0.1, stealth = false, groundRange = 0, isWeapon = true, }
unitTable["corfus"] = { radarRadius = 0, techLevel = 5, isBuilding = true, buildTime = 75424, needsWater = false, extractsMetal = 0, bigExplosion = true, airLosRadius = 409.5, losRadius = 273, wreckName = "corfus_dead", sonarRadius = 0, metalCost = 4483, xsize = 10, submergedRange = 0, jammerRadius = 0, zsize = 10, energyCost = 26978, mtype = "veh", airRange = 0, totalEnergyOut = 1100, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["corgant"] = { radarRadius = 50, techLevel = 5, isBuilding = true, buildTime = 67321, factoriesCanBuild = { }, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 409.5, wreckName = "corgant_dead", losRadius = 273, zsize = 18, sonarRadius = 0, metalCost = 8371, xsize = 18, submergedRange = 0, jammerRadius = 0, buildOptions = true, energyCost = 62426, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["corgantuw"] = { radarRadius = 50, techLevel = 5, isBuilding = true, buildTime = 67321, factoriesCanBuild = { }, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 409.5, wreckName = "corgantuw_dead", losRadius = 273, zsize = 18, sonarRadius = 0, metalCost = 8371, xsize = 18, submergedRange = 0, jammerRadius = 0, buildOptions = true, energyCost = 62426, mtype = "sub", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["corgarp"] = { radarRadius = 0, techLevel = 2, isBuilding = false, buildTime = 3101, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 351, losRadius = 234, wreckName = "corgarp_dead", sonarRadius = 0, metalCost = 220, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 2604, mtype = "amp", airRange = 0, totalEnergyOut = 0.19999999, stealth = false, groundRange = 305, isWeapon = true, }
unitTable["corgate"] = { radarRadius = 0, techLevel = 5, isBuilding = true, buildTime = 57166, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 409.5, losRadius = 273, wreckName = "corgate_dead", sonarRadius = 0, metalCost = 3985, xsize = 8, submergedRange = 0, jammerRadius = 0, zsize = 8, energyCost = 68089, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 500, isWeapon = false, }
unitTable["corgator"] = { radarRadius = 0, techLevel = 2, isBuilding = false, buildTime = 1761, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 409.5, losRadius = 273, wreckName = "corgator_dead", sonarRadius = 0, metalCost = 126, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 1111, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 230, isWeapon = true, }
unitTable["corgeo"] = { radarRadius = 0, techLevel = 3, isBuilding = true, buildTime = 12875, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 409.5, losRadius = 273, wreckName = "corgeo_dead", sonarRadius = 0, metalCost = 539, xsize = 8, submergedRange = 0, jammerRadius = 0, zsize = 8, energyCost = 13200, mtype = "veh", airRange = 0, totalEnergyOut = 300, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["corgol"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 26125, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 592.5, losRadius = 395, wreckName = "corgol_dead", sonarRadius = 0, metalCost = 1671, xsize = 8, submergedRange = 0, jammerRadius = 0, zsize = 8, energyCost = 21218, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 650, isWeapon = true, }
unitTable["corgripn"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 21522, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 585, losRadius = 390, wreckName = "", sonarRadius = 0, metalCost = 173, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 17457, mtype = "air", airRange = 0, totalEnergyOut = 0, stealth = true, groundRange = 1280, isWeapon = true, }
unitTable["corhlt"] = { radarRadius = 0, techLevel = 3, isBuilding = true, buildTime = 12650, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 682.5, losRadius = 455, wreckName = "corhlt_dead", sonarRadius = 0, metalCost = 479, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 4739, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 620, isWeapon = true, }
unitTable["corhp"] = { radarRadius = 50, techLevel = 2.5, isBuilding = true, buildTime = 14253, factoriesCanBuild = { }, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 468, wreckName = "corhp_dead", losRadius = 312, zsize = 14, sonarRadius = 0, metalCost = 1087, xsize = 16, submergedRange = 0, jammerRadius = 0, buildOptions = true, energyCost = 4336, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["corhrk"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 6591, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 555.75, losRadius = 370.5, wreckName = "corhrk_dead", sonarRadius = 0, metalCost = 597, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 5874, mtype = "bot", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 1210, isWeapon = true, }
unitTable["corhunt"] = { radarRadius = 2200, techLevel = 4, isBuilding = false, buildTime = 9512, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 1695, losRadius = 1130, wreckName = "", sonarRadius = 900, metalCost = 130, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 6849, mtype = "air", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["corhurc"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 36461, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 331.5, losRadius = 221, wreckName = "", sonarRadius = 0, metalCost = 317, xsize = 8, submergedRange = 0, jammerRadius = 0, zsize = 8, energyCost = 26783, mtype = "air", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 1280, isWeapon = true, }
unitTable["corint"] = { radarRadius = 0, techLevel = 5, isBuilding = true, buildTime = 93237, needsWater = false, extractsMetal = 0, bigExplosion = true, airLosRadius = 409.5, losRadius = 273, wreckName = "corint_dead", sonarRadius = 0, metalCost = 4617, xsize = 10, submergedRange = 0, jammerRadius = 0, zsize = 10, energyCost = 66688, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 4950, isWeapon = true, }
unitTable["corjamt"] = { radarRadius = 0, techLevel = 3, isBuilding = true, buildTime = 4577, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 156, losRadius = 104, wreckName = "corjamt_dead", sonarRadius = 0, metalCost = 116, xsize = 4, submergedRange = 0, jammerRadius = 360, zsize = 4, energyCost = 5110, mtype = "veh", airRange = 0, totalEnergyOut = -25, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["corkarg"] = { radarRadius = 0, techLevel = 6, isBuilding = false, buildTime = 50609, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 682.5, losRadius = 455, wreckName = "corkarg_dead", sonarRadius = 0, metalCost = 1664, xsize = 8, submergedRange = 0, jammerRadius = 0, zsize = 8, energyCost = 37082, mtype = "bot", airRange = 700, totalEnergyOut = 0, stealth = false, groundRange = 600, isWeapon = true, }
unitTable["corkrog"] = { radarRadius = 0, techLevel = 6, isBuilding = false, buildTime = 552145, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 1267.5, losRadius = 845, wreckName = "corkrog_dead", sonarRadius = 0, metalCost = 28994, xsize = 10, submergedRange = 0, jammerRadius = 0, zsize = 10, energyCost = 615508, mtype = "bot", airRange = 0, totalEnergyOut = 35, stealth = false, groundRange = 950, isWeapon = true, }
unitTable["corlab"] = { radarRadius = 50, techLevel = 1, isBuilding = true, buildTime = 7000, factoriesCanBuild = { }, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 430.949982, wreckName = "corlab_dead", losRadius = 287.299988, zsize = 12, sonarRadius = 0, metalCost = 619, xsize = 12, submergedRange = 0, jammerRadius = 0, buildOptions = true, energyCost = 1333, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["corlevlr"] = { radarRadius = 0, techLevel = 2, isBuilding = false, buildTime = 3009, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 429, losRadius = 286, wreckName = "corlevlr_dead", sonarRadius = 0, metalCost = 224, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 2546, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 315, isWeapon = true, }
unitTable["corllt"] = { radarRadius = 0, techLevel = 1, isBuilding = true, buildTime = 2724, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 741, losRadius = 494, wreckName = "corllt_dead", sonarRadius = 0, metalCost = 90, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 695, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 435, isWeapon = true, }
unitTable["cormabm"] = { radarRadius = 50, techLevel = 4, isBuilding = false, buildTime = 42000, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 675, losRadius = 450, wreckName = "cormabm_dead", sonarRadius = 0, metalCost = 1227, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 32427, mtype = "veh", airRange = 0, totalEnergyOut = 200, stealth = false, groundRange = 72000, isWeapon = true, }
unitTable["cormakr"] = { radarRadius = 0, techLevel = 1, isBuilding = true, buildTime = 2682, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 409.5, losRadius = 273, wreckName = "", sonarRadius = 0, metalCost = 1, xsize = 8, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 1233, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["cormart"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 4270, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 448.5, losRadius = 299, wreckName = "cormart_dead", sonarRadius = 0, metalCost = 281, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 3205, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 905, isWeapon = true, }
unitTable["cormaw"] = { radarRadius = 0, techLevel = 3, isBuilding = false, buildTime = 4419, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 633, losRadius = 422, wreckName = "cormaw_dead", sonarRadius = 0, metalCost = 291, xsize = 4, submergedRange = 0, jammerRadius = 8, zsize = 4, energyCost = 1506, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = true, groundRange = 410, isWeapon = true, }
unitTable["cormex"] = { radarRadius = 0, techLevel = 1, isBuilding = true, buildTime = 1874, needsWater = false, extractsMetal = 0.001, bigExplosion = false, airLosRadius = 409.5, losRadius = 273, wreckName = "cormex_dead", sonarRadius = 0, metalCost = 54, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 548, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["cormexp"] = { radarRadius = 0, techLevel = 5, isBuilding = true, buildTime = 32500, needsWater = false, extractsMetal = 0.004, bigExplosion = false, airLosRadius = 1014, losRadius = 676, wreckName = "cormexp_dead", sonarRadius = 0, metalCost = 2367, xsize = 10, submergedRange = 0, jammerRadius = 0, zsize = 10, energyCost = 12929, mtype = "veh", airRange = 0, totalEnergyOut = -12, stealth = false, groundRange = 650, isWeapon = true, }
unitTable["cormh"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 3579, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 763.5, losRadius = 509, wreckName = "cormh_dead", sonarRadius = 0, metalCost = 195, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 3314, mtype = "hov", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 700, isWeapon = true, }
unitTable["cormine1"] = { radarRadius = 0, techLevel = 3, isBuilding = false, buildTime = 50, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 124.799995, losRadius = 83.1999969, wreckName = "", sonarRadius = 0, metalCost = 5, xsize = 2, submergedRange = 0, jammerRadius = 0, zsize = 2, energyCost = 267, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = true, groundRange = 64, isWeapon = true, }
unitTable["cormine2"] = { radarRadius = 0, techLevel = 5, isBuilding = false, buildTime = 100, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 124.799995, losRadius = 83.1999969, wreckName = "", sonarRadius = 0, metalCost = 16, xsize = 2, submergedRange = 0, jammerRadius = 0, zsize = 2, energyCost = 1067, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = true, groundRange = 64, isWeapon = true, }
unitTable["cormine3"] = { radarRadius = 0, techLevel = 3, isBuilding = false, buildTime = 125, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 124.799995, losRadius = 83.1999969, wreckName = "", sonarRadius = 0, metalCost = 21, xsize = 2, submergedRange = 0, jammerRadius = 0, zsize = 2, energyCost = 1333, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = true, groundRange = 64, isWeapon = true, }
unitTable["cormine4"] = { radarRadius = 0, techLevel = 5, isBuilding = false, buildTime = 200, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 124.799995, losRadius = 83.1999969, wreckName = "", sonarRadius = 0, metalCost = 16, xsize = 2, submergedRange = 0, jammerRadius = 0, zsize = 2, energyCost = 1067, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = true, groundRange = 64, isWeapon = true, }
unitTable["cormist"] = { radarRadius = 0, techLevel = 2, isBuilding = false, buildTime = 3435, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 900, losRadius = 620, wreckName = "cormist_dead", sonarRadius = 0, metalCost = 156, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 2322, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 600, isWeapon = true, }
unitTable["cormls"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 5352, factoriesCanBuild = { "corsy", "corfhp", "csubpen", }, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 390, wreckName = "cormls_dead", losRadius = 260, zsize = 6, sonarRadius = 0, metalCost = 257, xsize = 6, submergedRange = 0, jammerRadius = 0, buildOptions = true, energyCost = 4162, mtype = "shp", airRange = 0, totalEnergyOut = 4.5, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["cormlv"] = { radarRadius = 0, techLevel = 2, isBuilding = false, buildTime = 3640, factoriesCanBuild = { }, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 282, wreckName = "cormlv_dead", losRadius = 188, zsize = 4, sonarRadius = 0, metalCost = 61, xsize = 4, submergedRange = 0, jammerRadius = 64, buildOptions = true, energyCost = 1298, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = true, groundRange = 200, isWeapon = false, }
unitTable["cormmkr"] = { radarRadius = 0, techLevel = 5, isBuilding = true, buildTime = 31253, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 409.5, losRadius = 273, wreckName = "cormmkr_dead", sonarRadius = 0, metalCost = 374, xsize = 8, submergedRange = 0, jammerRadius = 0, zsize = 8, energyCost = 20190, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["cormoho"] = { radarRadius = 0, techLevel = 5, isBuilding = true, buildTime = 14125, needsWater = false, extractsMetal = 0.004, bigExplosion = false, airLosRadius = 409.5, losRadius = 273, wreckName = "cormoho_dead", sonarRadius = 0, metalCost = 638, xsize = 10, submergedRange = 0, jammerRadius = 0, zsize = 10, energyCost = 8189, mtype = "veh", airRange = 0, totalEnergyOut = -25, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["cormort"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 5139, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 450, losRadius = 300, wreckName = "cormort_dead", sonarRadius = 0, metalCost = 407, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 2203, mtype = "bot", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 850, isWeapon = true, }
unitTable["cormship"] = { radarRadius = 1400, techLevel = 4, isBuilding = false, buildTime = 22126, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 477.75, losRadius = 318.5, wreckName = "cormship_dead", sonarRadius = 0, metalCost = 3083, xsize = 8, submergedRange = 0, jammerRadius = 0, zsize = 8, energyCost = 16915, mtype = "shp", airRange = 710, totalEnergyOut = 4.5, stealth = false, groundRange = 1550, isWeapon = true, }
unitTable["cormstor"] = { radarRadius = 0, techLevel = 1, isBuilding = true, buildTime = 2925, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 409.5, losRadius = 273, wreckName = "cormstor_dead", sonarRadius = 0, metalCost = 341, xsize = 10, submergedRange = 0, jammerRadius = 0, zsize = 10, energyCost = 587, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["cormuskrat"] = { radarRadius = 0, techLevel = 2, isBuilding = false, buildTime = 6864, factoriesCanBuild = { "corlab", "corvp", "corap", "corhp", "csubpen", "corsy", "csubpen", }, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 390, wreckName = "cormuskrat_dead", losRadius = 260, zsize = 6, sonarRadius = 0, metalCost = 172, xsize = 6, submergedRange = 0, jammerRadius = 0, buildOptions = true, energyCost = 3430, mtype = "amp", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["cornanotc"] = { radarRadius = 0, techLevel = 3, isBuilding = false, buildTime = 5312, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 570, losRadius = 380, wreckName = "", sonarRadius = 0, metalCost = 210, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 3222, mtype = "veh", airRange = 0, totalEnergyOut = -30, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["cornecro"] = { radarRadius = 50, techLevel = 2, isBuilding = false, buildTime = 2400, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 645, losRadius = 430, wreckName = "cornecro_dead", sonarRadius = 0, metalCost = 109, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 1493, mtype = "bot", airRange = 0, totalEnergyOut = 0, stealth = true, groundRange = 0, isWeapon = false, }
unitTable["corparrow"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 22181, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 577.5, losRadius = 385, wreckName = "corparrow_dead", sonarRadius = 0, metalCost = 1054, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 28644, mtype = "amp", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 575, isWeapon = true, }
unitTable["corplat"] = { radarRadius = 50, techLevel = 3, isBuilding = true, buildTime = 17102, factoriesCanBuild = { }, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 253.5, wreckName = "corplat_dead", losRadius = 169, zsize = 14, sonarRadius = 0, metalCost = 1631, xsize = 14, submergedRange = 0, jammerRadius = 0, buildOptions = true, energyCost = 18486, mtype = "shp", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["corpt"] = { radarRadius = 0, techLevel = 2, isBuilding = false, buildTime = 1877, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 800, losRadius = 585, wreckName = "corpt_dead", sonarRadius = 0, metalCost = 101, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 978, mtype = "shp", airRange = 760, totalEnergyOut = 4.5, stealth = false, groundRange = 260, isWeapon = true, }
unitTable["corptl"] = { radarRadius = 0, techLevel = 1, isBuilding = true, buildTime = 6350, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 450, losRadius = 300, wreckName = "corptl_dead", sonarRadius = 0, metalCost = 337, xsize = 6, submergedRange = 550, jammerRadius = 0, zsize = 6, energyCost = 2195, mtype = "sub", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = true, }
unitTable["corpun"] = { radarRadius = 0, techLevel = 3, isBuilding = true, buildTime = 19268, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 682.5, losRadius = 455, wreckName = "corpun_dead", sonarRadius = 0, metalCost = 1566, xsize = 8, submergedRange = 0, jammerRadius = 0, zsize = 8, energyCost = 13424, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 1245, isWeapon = true, }
unitTable["corpyro"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 5027, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 477, losRadius = 318, wreckName = "corpyro_heap", sonarRadius = 0, metalCost = 202, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 2969, mtype = "bot", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 230, isWeapon = true, }
unitTable["corrad"] = { radarRadius = 2100, techLevel = 1, isBuilding = true, buildTime = 1137, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 1020, losRadius = 680, wreckName = "corrad_dead", sonarRadius = 0, metalCost = 58, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 640, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["corraid"] = { radarRadius = 0, techLevel = 2, isBuilding = false, buildTime = 3312, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 487.5, losRadius = 325, wreckName = "corraid_dead", sonarRadius = 0, metalCost = 225, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 2367, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 350, isWeapon = true, }
unitTable["correap"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 11501, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 693, losRadius = 462, wreckName = "correap_dead", sonarRadius = 0, metalCost = 628, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 10289, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 410, isWeapon = true, }
unitTable["correcl"] = { radarRadius = 0, techLevel = 2, isBuilding = false, buildTime = 7596, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 645, losRadius = 430, wreckName = "", sonarRadius = 270, metalCost = 421, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 4204, mtype = "sub", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["corrl"] = { radarRadius = 0, techLevel = 1, isBuilding = true, buildTime = 1749, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 700, losRadius = 455, wreckName = "corrl_dead", sonarRadius = 0, metalCost = 81, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 859, mtype = "veh", airRange = 765, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = true, }
unitTable["corroach"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 7899, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 390, losRadius = 260, wreckName = "", sonarRadius = 0, metalCost = 69, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 5836, mtype = "bot", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 80, isWeapon = true, }
unitTable["corroy"] = { radarRadius = 0, techLevel = 2, isBuilding = false, buildTime = 13368, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 735, losRadius = 490, wreckName = "corroy_dead", sonarRadius = 400, metalCost = 1089, xsize = 6, submergedRange = 400, jammerRadius = 0, zsize = 6, energyCost = 6140, mtype = "shp", airRange = 0, totalEnergyOut = 4.5, stealth = false, groundRange = 710, isWeapon = true, }
unitTable["corsb"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 25022, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 682.5, losRadius = 455, wreckName = "", sonarRadius = 0, metalCost = 269, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 29798, mtype = "air", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 1280, isWeapon = true, }
unitTable["corsd"] = { radarRadius = 0, techLevel = 5, isBuilding = true, buildTime = 11955, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 337.5, losRadius = 225, wreckName = "corsd_dead", sonarRadius = 0, metalCost = 745, xsize = 8, submergedRange = 0, jammerRadius = 0, zsize = 8, energyCost = 6787, mtype = "veh", airRange = 0, totalEnergyOut = -125, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["corseal"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 12051, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 598.5, losRadius = 399, wreckName = "corseal_dead", sonarRadius = 0, metalCost = 480, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 9067, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 440, isWeapon = true, }
unitTable["corseap"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 10698, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 682.5, losRadius = 455, wreckName = "", sonarRadius = 0, metalCost = 245, xsize = 6, submergedRange = 500, jammerRadius = 0, zsize = 6, energyCost = 6171, mtype = "air", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = true, }
unitTable["corsent"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 11986, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 900, losRadius = 338, wreckName = "corsent_dead", sonarRadius = 0, metalCost = 473, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 10119, mtype = "veh", airRange = 800, totalEnergyOut = -0.5, stealth = false, groundRange = 0, isWeapon = true, }
unitTable["corsfig"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 6915, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 700, losRadius = 200, wreckName = "", sonarRadius = 0, metalCost = 68, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 3795, mtype = "air", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 520, isWeapon = true, }
unitTable["corsh"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 4079, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 763.5, losRadius = 509, wreckName = "corsh_dead", sonarRadius = 0, metalCost = 76, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 1535, mtype = "hov", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 230, isWeapon = true, }
unitTable["corshad"] = { radarRadius = 0, techLevel = 2, isBuilding = false, buildTime = 5054, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 253.5, losRadius = 169, wreckName = "", sonarRadius = 0, metalCost = 148, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 4655, mtype = "air", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 1280, isWeapon = true, }
unitTable["corshark"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 15529, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 585, losRadius = 390, wreckName = "corshark_dead", sonarRadius = 525, metalCost = 1020, xsize = 6, submergedRange = 600, jammerRadius = 0, zsize = 6, energyCost = 9861, mtype = "sub", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = true, }
unitTable["corshroud"] = { radarRadius = 0, techLevel = 5, isBuilding = true, buildTime = 9392, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 232.5, losRadius = 155, wreckName = "corshroud_dead", sonarRadius = 0, metalCost = 132, xsize = 4, submergedRange = 0, jammerRadius = 700, zsize = 4, energyCost = 19524, mtype = "veh", airRange = 0, totalEnergyOut = -125, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["corsilo"] = { radarRadius = 50, techLevel = 5, isBuilding = true, buildTime = 181243, needsWater = false, extractsMetal = 0, bigExplosion = true, airLosRadius = 682.5, losRadius = 455, wreckName = "corsilo_dead", sonarRadius = 0, metalCost = 7666, xsize = 14, submergedRange = 0, jammerRadius = 0, zsize = 14, energyCost = 82705, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 72000, isWeapon = true, }
unitTable["corsjam"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 7025, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 604.5, losRadius = 403, wreckName = "corsjam_dead", sonarRadius = 0, metalCost = 144, xsize = 6, submergedRange = 0, jammerRadius = 900, zsize = 6, energyCost = 2404, mtype = "shp", airRange = 0, totalEnergyOut = 4.5, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["corsktl"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 16975, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 390, losRadius = 260, wreckName = "", sonarRadius = 0, metalCost = 540, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 26371, mtype = "bot", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 80, isWeapon = true, }
unitTable["corsnap"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 3791, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 736.5, losRadius = 491, wreckName = "corsnap_dead", sonarRadius = 0, metalCost = 316, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 3313, mtype = "hov", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 320, isWeapon = true, }
unitTable["corsok"] = { radarRadius = 0, techLevel = 6, isBuilding = false, buildTime = 63001, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 975, losRadius = 650, wreckName = "corsok_dead", sonarRadius = 700, metalCost = 4171, xsize = 8, submergedRange = 725, jammerRadius = 0, zsize = 8, energyCost = 62364, mtype = "hov", airRange = 0, totalEnergyOut = 0.20000005, stealth = false, groundRange = 725, isWeapon = true, }
unitTable["corsolar"] = { radarRadius = 0, techLevel = 1, isBuilding = true, buildTime = 2766, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 409.5, losRadius = 273, wreckName = "corsolar_dead", sonarRadius = 0, metalCost = 150, xsize = 10, submergedRange = 0, jammerRadius = 0, zsize = 10, energyCost = 0, mtype = "veh", airRange = 0, totalEnergyOut = 20, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["corsonar"] = { radarRadius = 0, techLevel = 1, isBuilding = true, buildTime = 900, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 727.5, losRadius = 485, wreckName = "corsonar_dead", sonarRadius = 1200, metalCost = 21, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 426, mtype = "sub", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["corspec"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 5439, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 375, losRadius = 250, wreckName = "corspec_dead", sonarRadius = 0, metalCost = 75, xsize = 4, submergedRange = 0, jammerRadius = 450, zsize = 4, energyCost = 1550, mtype = "bot", airRange = 0, totalEnergyOut = -92, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["corspy"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 22247, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 825, losRadius = 550, wreckName = "corspy_dead", sonarRadius = 0, metalCost = 166, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 12215, mtype = "bot", airRange = 0, totalEnergyOut = 0, stealth = true, groundRange = 0, isWeapon = false, }
unitTable["corssub"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 23007, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 780, losRadius = 520, wreckName = "corssub_dead", sonarRadius = 550, metalCost = 1874, xsize = 6, submergedRange = 690, jammerRadius = 0, zsize = 6, energyCost = 12736, mtype = "sub", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = true, }
unitTable["corstorm"] = { radarRadius = 0, techLevel = 2, isBuilding = false, buildTime = 1949, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 516.75, losRadius = 344.5, wreckName = "corstorm_dead", sonarRadius = 0, metalCost = 112, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 1129, mtype = "bot", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 475, isWeapon = true, }
unitTable["corsub"] = { radarRadius = 0, techLevel = 2, isBuilding = false, buildTime = 10895, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 600, losRadius = 400, wreckName = "corsub_dead", sonarRadius = 475, metalCost = 724, xsize = 4, submergedRange = 500, jammerRadius = 0, zsize = 4, energyCost = 4162, mtype = "sub", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = true, }
unitTable["corsumo"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 50975, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 765, losRadius = 510, wreckName = "corsumo_dead", sonarRadius = 0, metalCost = 2155, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 35799, mtype = "bot", airRange = 0, totalEnergyOut = 17.5, stealth = false, groundRange = 650, isWeapon = true, }
unitTable["corsy"] = { radarRadius = 0, techLevel = 1, isBuilding = true, buildTime = 6000, factoriesCanBuild = { }, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 510, wreckName = "corsy_dead", losRadius = 340, zsize = 16, sonarRadius = 0, metalCost = 443, xsize = 16, submergedRange = 0, jammerRadius = 0, buildOptions = true, energyCost = 800, mtype = "shp", airRange = 0, totalEnergyOut = 15, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["cortarg"] = { radarRadius = 0, techLevel = 5, isBuilding = true, buildTime = 10898, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 409.5, losRadius = 273, wreckName = "cortarg_dead", sonarRadius = 0, metalCost = 799, xsize = 10, submergedRange = 0, jammerRadius = 0, zsize = 8, energyCost = 7529, mtype = "veh", airRange = 0, totalEnergyOut = -100, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["cortermite"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 18834, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 570, losRadius = 380, wreckName = "cortermite_dead", sonarRadius = 0, metalCost = 695, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 12100, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 340, isWeapon = true, }
unitTable["corthovr"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 19587, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 487.5, losRadius = 325, wreckName = "corthovr_dead", sonarRadius = 0, metalCost = 693, xsize = 8, submergedRange = 0, jammerRadius = 0, zsize = 8, energyCost = 8044, mtype = "hov", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = true, }
unitTable["corthud"] = { radarRadius = 0, techLevel = 2, isBuilding = false, buildTime = 1971, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 570, losRadius = 380, wreckName = "corthud_dead", sonarRadius = 0, metalCost = 141, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 1132, mtype = "bot", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 380, isWeapon = true, }
unitTable["cortide"] = { radarRadius = 0, techLevel = 1, isBuilding = true, buildTime = 2094, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 195, losRadius = 130, wreckName = "cortide_dead", sonarRadius = 0, metalCost = 86, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 311, mtype = "shp", airRange = 0, totalEnergyOut = 10, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["cortitan"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 14722, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 682.5, losRadius = 455, wreckName = "", sonarRadius = 0, metalCost = 339, xsize = 6, submergedRange = 500, jammerRadius = 0, zsize = 6, energyCost = 7241, mtype = "air", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = true, }
unitTable["cortl"] = { radarRadius = 0, techLevel = 3, isBuilding = true, buildTime = 8466, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 682.5, losRadius = 455, wreckName = "cortl_dead", sonarRadius = 0, metalCost = 337, xsize = 6, submergedRange = 550, jammerRadius = 0, zsize = 6, energyCost = 2195, mtype = "shp", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = true, }
unitTable["cortoast"] = { radarRadius = 0, techLevel = 5, isBuilding = true, buildTime = 25717, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 624, losRadius = 416, wreckName = "cortoast_dead", sonarRadius = 0, metalCost = 2473, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 17189, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 1335, isWeapon = true, }
unitTable["cortron"] = { radarRadius = 0, techLevel = 5, isBuilding = true, buildTime = 58927, needsWater = false, extractsMetal = 0, bigExplosion = true, airLosRadius = 682.5, losRadius = 455, wreckName = "cortron_dead", sonarRadius = 0, metalCost = 804, xsize = 8, submergedRange = 0, jammerRadius = 0, zsize = 8, energyCost = 13938, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 2750, isWeapon = true, }
unitTable["cortship"] = { radarRadius = 0, techLevel = 2, isBuilding = false, buildTime = 9564, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 825, losRadius = 550, wreckName = "cortship_dead", sonarRadius = 0, metalCost = 757, xsize = 8, submergedRange = 0, jammerRadius = 0, zsize = 8, energyCost = 6705, mtype = "shp", airRange = 0, totalEnergyOut = 4.5, stealth = false, groundRange = 0, isWeapon = true, }
unitTable["coruwadves"] = { radarRadius = 0, techLevel = 5, isBuilding = true, buildTime = 20416, needsWater = false, extractsMetal = 0, bigExplosion = true, airLosRadius = 288, losRadius = 192, wreckName = "coruwadves_dead", sonarRadius = 0, metalCost = 843, xsize = 10, submergedRange = 0, jammerRadius = 0, zsize = 10, energyCost = 10701, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["coruwadvms"] = { radarRadius = 0, techLevel = 5, isBuilding = true, buildTime = 20524, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 273, losRadius = 182, wreckName = "coruwadvms_dead", sonarRadius = 0, metalCost = 757, xsize = 8, submergedRange = 0, jammerRadius = 0, zsize = 8, energyCost = 11093, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["coruwes"] = { radarRadius = 0, techLevel = 1, isBuilding = true, buildTime = 7241, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 253.5, losRadius = 169, wreckName = "coruwes_dead", sonarRadius = 0, metalCost = 299, xsize = 8, submergedRange = 0, jammerRadius = 0, zsize = 8, energyCost = 2709, mtype = "sub", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["coruwfus"] = { radarRadius = 0, techLevel = 5, isBuilding = true, buildTime = 105004, needsWater = true, extractsMetal = 0, bigExplosion = true, airLosRadius = 214.5, losRadius = 143, wreckName = "coruwfus_dead", sonarRadius = 0, metalCost = 5379, xsize = 10, submergedRange = 0, jammerRadius = 0, zsize = 10, energyCost = 33723, mtype = "sub", airRange = 0, totalEnergyOut = 1220, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["coruwmex"] = { radarRadius = 0, techLevel = 1, isBuilding = true, buildTime = 1887, needsWater = true, extractsMetal = 0.001, bigExplosion = false, airLosRadius = 253.5, losRadius = 169, wreckName = "coruwmex_dead", sonarRadius = 0, metalCost = 60, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 554, mtype = "sub", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["coruwmme"] = { radarRadius = 0, techLevel = 5, isBuilding = true, buildTime = 34783, needsWater = true, extractsMetal = 0.004, bigExplosion = false, airLosRadius = 253.5, losRadius = 169, wreckName = "coruwmme_dead", sonarRadius = 0, metalCost = 811, xsize = 10, submergedRange = 0, jammerRadius = 0, zsize = 10, energyCost = 10748, mtype = "sub", airRange = 0, totalEnergyOut = -25, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["coruwmmm"] = { radarRadius = 0, techLevel = 5, isBuilding = true, buildTime = 38623, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 214.5, losRadius = 143, wreckName = "coruwmmm_dead", sonarRadius = 0, metalCost = 401, xsize = 10, submergedRange = 0, jammerRadius = 0, zsize = 10, energyCost = 23636, mtype = "shp", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["coruwms"] = { radarRadius = 0, techLevel = 1, isBuilding = true, buildTime = 3874, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 253.5, losRadius = 169, wreckName = "coruwms_dead", sonarRadius = 0, metalCost = 373, xsize = 8, submergedRange = 0, jammerRadius = 0, zsize = 8, energyCost = 1625, mtype = "sub", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["corvalk"] = { radarRadius = 0, techLevel = 2, isBuilding = false, buildTime = 4122, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 390, losRadius = 260, wreckName = "", sonarRadius = 0, metalCost = 74, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 1437, mtype = "air", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = true, }
unitTable["corvamp"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 6554, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 800, losRadius = 200, wreckName = "", sonarRadius = 0, metalCost = 105, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 3678, mtype = "air", airRange = 550, totalEnergyOut = 0, stealth = true, groundRange = 550, isWeapon = true, }
unitTable["corveng"] = { radarRadius = 0, techLevel = 2, isBuilding = false, buildTime = 3333, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 700, losRadius = 200, wreckName = "", sonarRadius = 0, metalCost = 73, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 2812, mtype = "air", airRange = 530, totalEnergyOut = 0, stealth = false, groundRange = 530, isWeapon = true, }
unitTable["corvipe"] = { radarRadius = 0, techLevel = 5, isBuilding = true, buildTime = 15035, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 819, losRadius = 546, wreckName = "corvipe_dead", sonarRadius = 0, metalCost = 730, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 14016, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 730, isWeapon = true, }
unitTable["corvoyr"] = { radarRadius = 2200, techLevel = 4, isBuilding = false, buildTime = 3945, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 1387.5, losRadius = 925, wreckName = "corvoyr_dead", sonarRadius = 0, metalCost = 99, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 1369, mtype = "bot", airRange = 0, totalEnergyOut = -12, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["corvp"] = { radarRadius = 50, techLevel = 1, isBuilding = true, buildTime = 7151, factoriesCanBuild = { }, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 418.5, wreckName = "corvp_dead", losRadius = 279, zsize = 14, sonarRadius = 0, metalCost = 771, xsize = 14, submergedRange = 0, jammerRadius = 0, buildOptions = true, energyCost = 1890, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["corvrad"] = { radarRadius = 2200, techLevel = 4, isBuilding = false, buildTime = 4223, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 1350, losRadius = 900, wreckName = "corvrad_dead", sonarRadius = 0, metalCost = 92, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 1290, mtype = "veh", airRange = 0, totalEnergyOut = -12, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["corvroc"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 15002, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 331.5, losRadius = 221, wreckName = "corvroc_dead", sonarRadius = 0, metalCost = 882, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 6688, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = true, groundRange = 1240, isWeapon = true, }
unitTable["corwin"] = { radarRadius = 0, techLevel = 1, isBuilding = true, buildTime = 1687, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 409.5, losRadius = 273, wreckName = "corwin_dead", sonarRadius = 0, metalCost = 45, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 174, mtype = "veh", airRange = 0, totalEnergyOut = 4.5, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["corwolv"] = { radarRadius = 0, techLevel = 2, isBuilding = false, buildTime = 3254, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 448.5, losRadius = 299, wreckName = "corwolv_dead", sonarRadius = 0, metalCost = 153, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 2367, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 710, isWeapon = true, }
unitTable["critter_ant"] = { radarRadius = 0, techLevel = -1, isBuilding = false, buildTime = 10, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 0, losRadius = 0, wreckName = "", sonarRadius = 0, metalCost = 1, xsize = 2, submergedRange = 0, jammerRadius = 0, zsize = 2, energyCost = 0, mtype = "bot", airRange = 0, totalEnergyOut = 0, stealth = true, groundRange = 0, isWeapon = false, }
unitTable["critter_duck"] = { radarRadius = 0, techLevel = -1, isBuilding = false, buildTime = 10, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 0, losRadius = 0, wreckName = "", sonarRadius = 0, metalCost = 1, xsize = 2, submergedRange = 0, jammerRadius = 0, zsize = 2, energyCost = 0, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = true, groundRange = 0, isWeapon = false, }
unitTable["critter_goldfish"] = { radarRadius = 0, techLevel = -1, isBuilding = false, buildTime = 600, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 0, losRadius = 0, wreckName = "", sonarRadius = 550, metalCost = 1, xsize = 2, submergedRange = 0, jammerRadius = 0, zsize = 2, energyCost = 0, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = true, groundRange = 0, isWeapon = false, }
unitTable["critter_gull"] = { radarRadius = 0, techLevel = -1, isBuilding = false, buildTime = 10, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 0, losRadius = 0, wreckName = "", sonarRadius = 0, metalCost = 1, xsize = 2, submergedRange = 0, jammerRadius = 0, zsize = 2, energyCost = 0, mtype = "air", airRange = 0, totalEnergyOut = 0, stealth = true, groundRange = 0, isWeapon = false, }
unitTable["critter_penguin"] = { radarRadius = 0, techLevel = -1, isBuilding = false, buildTime = 10, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 0, losRadius = 0, wreckName = "", sonarRadius = 0, metalCost = 1, xsize = 2, submergedRange = 0, jammerRadius = 0, zsize = 2, energyCost = 0, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = true, groundRange = 0, isWeapon = false, }
unitTable["csubpen"] = { radarRadius = 0, techLevel = 3, isBuilding = true, buildTime = 11402, factoriesCanBuild = { }, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 360, wreckName = "csubpen_dead", losRadius = 240, zsize = 16, sonarRadius = 0, metalCost = 1271, xsize = 16, submergedRange = 0, jammerRadius = 0, buildOptions = true, energyCost = 5637, mtype = "sub", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = false, }
unitTable["decade"] = { radarRadius = 0, techLevel = 2, isBuilding = false, buildTime = 6525, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 643.5, losRadius = 429, wreckName = "decade_dead", sonarRadius = 0, metalCost = 322, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 2630, mtype = "shp", airRange = 0, totalEnergyOut = 4.5, stealth = false, groundRange = 310, isWeapon = true, }
unitTable["gorg"] = { radarRadius = 0, techLevel = 6, isBuilding = false, buildTime = 629630, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 1080, losRadius = 720, wreckName = "gorg_dead", sonarRadius = 0, metalCost = 19952, xsize = 10, submergedRange = 0, jammerRadius = 0, zsize = 10, energyCost = 513243, mtype = "bot", airRange = 0, totalEnergyOut = 35, stealth = false, groundRange = 590, isWeapon = true, }
unitTable["hllt"] = { radarRadius = 0, techLevel = 3, isBuilding = true, buildTime = 5448, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 712.5, losRadius = 475, wreckName = "hllt_dead", sonarRadius = 0, metalCost = 197, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 1725, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 475, isWeapon = true, }
unitTable["intruder"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 14177, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 438, losRadius = 292, wreckName = "intruder_dead", sonarRadius = 0, metalCost = 1348, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 16011, mtype = "hov", airRange = 0, totalEnergyOut = -0.3000002, stealth = false, groundRange = 0, isWeapon = true, }
unitTable["krogtaar"] = { radarRadius = 0, techLevel = -1, isBuilding = false, buildTime = 101125, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 585, losRadius = 390, wreckName = "krogtaar_dead", sonarRadius = 0, metalCost = 7236, xsize = 8, submergedRange = 0, jammerRadius = 0, zsize = 8, energyCost = 53866, mtype = "bot", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 465, isWeapon = true, }
unitTable["madsam"] = { radarRadius = 0, techLevel = 3, isBuilding = true, buildTime = 5237, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 850, losRadius = 375, wreckName = "madsam_dead", sonarRadius = 0, metalCost = 315, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 6133, mtype = "veh", airRange = 840, totalEnergyOut = -5, stealth = false, groundRange = 0, isWeapon = true, }
unitTable["marauder"] = { radarRadius = 0, techLevel = 6, isBuilding = false, buildTime = 28957, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 682.5, losRadius = 455, wreckName = "marauder_dead", sonarRadius = 0, metalCost = 971, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 20836, mtype = "bot", airRange = 600, totalEnergyOut = 0, stealth = false, groundRange = 350, isWeapon = true, }
unitTable["mercury"] = { radarRadius = 0, techLevel = 5, isBuilding = true, buildTime = 30190, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 2400, losRadius = 350, wreckName = "mercury_dead", sonarRadius = 0, metalCost = 1623, xsize = 8, submergedRange = 0, jammerRadius = 0, zsize = 8, energyCost = 32262, mtype = "veh", airRange = 2400, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = true, }
unitTable["meteor"] = { radarRadius = 900, techLevel = -1, isBuilding = true, buildTime = 1, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 675, losRadius = 450, wreckName = "", sonarRadius = 0, metalCost = 1, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 1, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 29999, isWeapon = false, }
unitTable["nsaclash"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 12907, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 523.5, losRadius = 349, wreckName = "nsaclash_dead", sonarRadius = 0, metalCost = 640, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 13025, mtype = "hov", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 275, isWeapon = true, }
unitTable["packo"] = { radarRadius = 0, techLevel = 3, isBuilding = true, buildTime = 5810, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 850, losRadius = 375, wreckName = "packo_dead", sonarRadius = 0, metalCost = 361, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 5714, mtype = "veh", airRange = 840, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = true, }
unitTable["screamer"] = { radarRadius = 0, techLevel = 5, isBuilding = true, buildTime = 30220, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 2400, losRadius = 350, wreckName = "screamer_dead", sonarRadius = 0, metalCost = 1632, xsize = 8, submergedRange = 0, jammerRadius = 0, zsize = 8, energyCost = 32386, mtype = "veh", airRange = 2400, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = true, }
unitTable["shiva"] = { radarRadius = 0, techLevel = 6, isBuilding = false, buildTime = 30609, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 448.5, losRadius = 299, wreckName = "shiva_dead", sonarRadius = 0, metalCost = 1538, xsize = 8, submergedRange = 0, jammerRadius = 0, zsize = 8, energyCost = 23332, mtype = "bot", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 800, isWeapon = true, }
unitTable["tawf001"] = { radarRadius = 0, techLevel = 3, isBuilding = true, buildTime = 5324, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 712.5, losRadius = 475, wreckName = "tawf001_dead", sonarRadius = 0, metalCost = 188, xsize = 4, submergedRange = 0, jammerRadius = 0, zsize = 4, energyCost = 1530, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 475, isWeapon = true, }
unitTable["tawf009"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 21087, needsWater = true, extractsMetal = 0, bigExplosion = false, airLosRadius = 702, losRadius = 468, wreckName = "tawf009_dead", sonarRadius = 550, metalCost = 1798, xsize = 6, submergedRange = 690, jammerRadius = 0, zsize = 6, energyCost = 12482, mtype = "sub", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 0, isWeapon = true, }
unitTable["tawf013"] = { radarRadius = 0, techLevel = 2, isBuilding = false, buildTime = 2998, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 546, losRadius = 364, wreckName = "tawf013_dead", sonarRadius = 0, metalCost = 135, xsize = 6, submergedRange = 0, jammerRadius = 0, zsize = 6, energyCost = 2150, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 710, isWeapon = true, }
unitTable["tawf114"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 23129, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 819, losRadius = 546, wreckName = "tawf114_dead", sonarRadius = 0, metalCost = 1002, xsize = 8, submergedRange = 0, jammerRadius = 0, zsize = 8, energyCost = 22081, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 800, isWeapon = true, }
unitTable["trem"] = { radarRadius = 0, techLevel = 4, isBuilding = false, buildTime = 31103, needsWater = false, extractsMetal = 0, bigExplosion = false, airLosRadius = 526.5, losRadius = 351, wreckName = "trem_dead", sonarRadius = 0, metalCost = 2081, xsize = 8, submergedRange = 0, jammerRadius = 0, zsize = 8, energyCost = 48373, mtype = "veh", airRange = 0, totalEnergyOut = 0, stealth = false, groundRange = 1275, isWeapon = true, }
